<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/11/14 10:06
 */

namespace api\modules\buyCar\controllers;

use api\models\LoginForm;
use api\models\RegisterForm;
use api\models\ResetPasswordForm;
use common\helpers\Utils;
use common\models\Announcement;
use common\models\SmsVerifycode;
use common\models\User;
use Yii;
use common\helpers\Erp;

header('Access-Control-Allow-Origin:*');

class AuthController extends ControllerBase
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        $behaviors = parent::behaviors();
        $behaviors['authenticator']['optional'] = ['login', 'register', 'reset', 'sms-verifycode', 'register-agreement', 'validate-sms-code', 'index-list', "get-qrcode"];
        return $behaviors;
    }

    /**
     * 登录
     * @return array
     */
    public function actionLogin()
    {
        $model = new LoginForm();
        if ($model->load(\Yii::$app->request->post(), '')) {
            if ($model->login()) {
                // 生成TOKEN
                $this->uid = $model->user->uid;
                $sign = md5($this->uid . TIMESTAMP . $model->user->access_token);
                $token = base64_encode(json_encode(['uid' => $this->uid, 'timestamp' => TIMESTAMP, 'sign' => $sign]));
                $data = [
                    'token' => $token,
                    'nickname' => $model->user->nickname,
                    'uid' => $model->user->uid,
                    'report' => $model->user->report,
                    'partner' => $model->user->partner,
                    'avatar' => !empty($model->user->avatar) ? Utils::toMedia($model->user->avatar) : '',
                ];
                return $this->responseJson(0, $data, '登录成功');
            } else {
                return $this->responseJson(1, '', current($model->getFirstErrors()));
            }
        }

        return $this->responseJson(404, '', '无效的访问');
    }

    /**
     * 注册
     * @return array
     * @throws \yii\base\Exception
     */
    public function actionRegister()
    {
        $model = new RegisterForm();
        $mobile = Yii::$app->request->post('referrer');
//        $user = User::findByUid($mobile); //根据推荐人id搜索
        $user = User::findByAccount($mobile); //根据推荐人登录账户搜索
        if (empty($user)) {
            return $this->responseJson(1, '', '推荐人未注册或者账号已被冻结！');
        }
//        if ($user->report_center != 1) {
//            return $this->responseJson(1, '', '推荐人还不是销售中心！');
//        }
        $ere= Yii::$app->request->post(); //接收到的所有的数据
        $exist=User::findByUsername($ere['userName']); //销售名唯一性验证
        if($exist->username==$ere['userName']){
            return $this->responseJson(1, '', '销售名已存在！');
        }
        $acc=User::findByAccountname($ere['accountname']);
        if(!empty($acc)){
            return $this->responseJson(1, '', '登录账号已存在！');
        }
        if ($model->load(Yii::$app->request->post(), '')) {
            $user = $model->register();
            if ($user !== false && !is_array($user)) {
                return $this->responseJson(0, $user, '注册成功');
            } else {
//                return $this->responseJson(1, [], '注册失败');
                return $this->responseJson(1, $user, '注册失败');
            }

        } else {
            return $this->responseJson(1, $model->mobile, current($model->getFirstErrors()));
        }
    }

    /**
     * 推荐注册
     * @return array
     * @throws \yii\base\Exception
     */
    public function actionUserRegister()
    {
        $model = new RegisterForm();
        if ($model->load(Yii::$app->request->post(), '') && $model->register()) {
            return $this->responseJson(0, $model->mobile, '注册成功');
        } else {
            return $this->responseJson(1, $model->mobile, current($model->getFirstErrors()));
        }
    }

    /**
     * 获取手机号
     * @return array
     */
    public function actionGetMobile()
    {
        $user = Yii::$app->user->identity;
        if (!empty($user)) {
            $mobile = !empty($user->mobile) ? $user->mobile : '';
        } else {
            $mobile = '';
        }
        return $this->responseJson(0, $mobile, '返回数据');

    }

    /**
     * 忘记密码
     * @return array
     */
    public function actionReset()
    {
        $model = new ResetPasswordForm();
        $model->scenario = 'password';
        if ($this->arrayLoad($model, Yii::$app->request->post()) && $model->resetPassword()) {
            //if ($model->load(Yii::$app->request->post(),'') && $model->resetPassword()) {
            return $this->responseJson(0, '', '密码设置成功，请登录！');
        } else {
            return $this->responseJson(1, '', current($model->getFirstErrors()));
        }
    }

    /**
     * 修改支付密码
     * @return array
     */
    public function actionResetPayPwd()
    {
        $model = new ResetPasswordForm();
        $model->scenario = 'pay_pwd';
        if ($this->arrayLoad($model, Yii::$app->request->post()) && $model->resetPayPwd()) {
            return $this->responseJson(0, '', '支付密码更新成功');
        } else {
            return $this->responseJson(1, '', current($model->getFirstErrors()));
        }
    }

    /**
     * 验证短信验证码
     * @return array
     */
    public function actionValidateSmsCode()
    {
        $mobile = \Yii::$app->request->post('mobile');
        $smsCode = \Yii::$app->request->post('smsCode');

        if (empty($mobile) || empty($smsCode)) {
            return $this->responseJson(0, '', '请填写正确的参数');
        }
        $smsVerifycode = new SmsVerifycode();
        $result = $smsVerifycode->check($mobile, $smsCode);
        if ($result === true) {
            return $this->responseJson(0, $mobile, '短信验证成功');
        } else {
            return $this->responseJson(1, $mobile, '短信验证失败');
        }
    }

    /**
     * 验证码
     * @return array
     */
    public function actionSmsVerifycode()
    {
        $mobile = \Yii::$app->request->post('mobile');
        $scenario = \Yii::$app->request->post('scenario') ?: 'register';
        if (empty($mobile) || strlen($mobile) != 11) {
            return $this->responseJson(1, '', '输入的手机号错误');
        }
        $smsVerifycode = new SmsVerifycode();
        $result = $smsVerifycode->send($mobile, $scenario);
        if ($result === true) {
            return $this->responseJson(0, '', '短信已发送，请注意查收！');
        } else {
            return $this->responseJson(1, '', $result);
        }
    }

    /**
     * 注册须知
     * @return array
     */
    public function actionRegisterAgreement()
    {
        $item = Announcement::find()->where("type = 5")->asArray()->one();
        if (!empty($item)) {
            return $this->responseJson(0, $item, '获取信息成功');
        } else {
            return $this->responseJson(1, '', '获取信息失败');
        }
    }


}
