<?php
/**
 * Created by PhpStorm.
 * User: XingBin
 * Date: 2017/8/17
 * Time: 10:18
 */

namespace backend\controllers;

use common\models\ArticleList;
use common\models\ArticleCategory;
use yii;
use common\models\ManagerLog;
class ArticleController extends ControllerBase
{
    //查询非幻灯和欢迎页的所有文章
    protected $condition = ' cid != 31 and cid != 26 ';
    //查询非幻灯和欢迎页的所有分类
    protected $cate_id = ' id != 31 and id != 26 ';
    //查询欢迎页文章
    protected $index_pic = 'cid = 31';
    //查询幻灯页文章
    protected $slide_pic = 'cid = 26';

    /**
     *
     * 文章列表
     */
    public function actionList()
    {
        $condition = "cid = 0";
        $keywords = trim(Yii::$app->request->get('keywords', ''));
        if (!empty($keywords)) {
            $condition .= " AND (id = '{$keywords}' OR title LIKE '%{$keywords}%')";
        }
        $list = ArticleList::find()->where($condition);
        $this->view->title = '文章列表';
        return $this->render('list', ['list' => $list, 'keywords' => $keywords]);

    }

    /**
     * 编辑文章/添加文章
     * @return string|yii\web\Response
     */
    public function actionUpdate()
    {
        $item = new ArticleList();
        $id = intval(Yii::$app->request->get('id'));
        if (!empty($id)) {
            $item = ArticleList::findOne($id);
            if (empty($item)) {
                return $this->message('您要编辑的文章不存在', ['article/list'], 'error');
            }
        } else {
            $item = $item->loadDefaultValues();
        }
        if ($item->load(Yii::$app->request->post())) {
            if ($item->validate() && $item->save()) {
                 $manager=new ManagerLog(); 
                 $manager->operate = "文章更新或者添加";
                $manager->params =base64_encode(serialize(Yii::$app->request->post()));
                 $result = $manager->save();
                return $this->message('更新成功', ['article/list'], 'success');
            } else {
                return $this->message('更新失败', ['article/list'], 'error');
            }
        }

        $area = ArticleCategory::find()->where($this->cate_id)->andWhere(['status' => 0])->asArray()->all();
        $tree = ArticleCategory::subtree($area, 0, 1);
        $list = array();
        foreach ($tree as $v) {
            $v['title'] = str_repeat(' - ', $v['lev']) . $v['title'];
            $list[] = $v;
        }
        return $this->render('update', [
            'list' => $list,
            'item' => $item
        ]);
    }

    /**
     * 图片放大
     * @return string
     */
    public function actionBigPic()
    {
        $id = Yii::$app->request->get('id');
        return $this->renderAjax('big-pic', ['pic' => $id]);
    }

    /**
     * 文章上下架
     * @return yii\web\Response
     * @throws \Throwable
     * @throws yii\db\StaleObjectException
     */
    public function actionStop()
    {
        $id = Yii::$app->request->get('id');
        if (empty($id)) {
            return $this->message('您要下架的文章不存在', ['article/list'], 'error');
        } else {
            $model = ArticleList::findOne($id);
            if ($model['status'] == 0) {
                $model->status = 9;
                $result = $model->update(true, ['status']);
                if ($result > 0) {
                    Yii::$app->getSession()->setFlash('success', '审核驳回成功');
                    return $this->redirect(['article/list']);
                } else {
                    Yii::$app->getSession()->setFlash('error', '审核驳回失败');
                    return $this->redirect(['article/list']);
                }
            } else {
                $model->status = 0;
                $result = $model->update(true, ['status']);
                if ($result > 0) {
                $manager=new ManagerLog(); 
                 $manager->operate = "文章上下架审核成功ID为".$id;
                 $result = $manager->save();
                    Yii::$app->getSession()->setFlash('success', '审核成功');
                    return $this->redirect(['article/list']);
                } else {
                    Yii::$app->getSession()->setFlash('error', '审核失败');
                    return $this->redirect(['article/list']);
                }
            }

        }
    }

    /**
     * 删除文章
     * @param $id
     * @return yii\web\Response
     * @throws \Throwable
     * @throws yii\db\StaleObjectException
     */
    public function actionDelete($id)
    {
        $item = ArticleList::findOne($id)->delete();
        if ($item > 0) {
            Yii::$app->getSession()->setFlash('success', '删除成功');
             $manager=new ManagerLog(); 
                 $manager->operate = "文章删除成功ID为".$id;
                 $result = $manager->save();
            return $this->redirect(['article/list']);
        } else {
            Yii::$app->getSession()->setFlash('error', '删除失败');
            return $this->redirect(['article/list']);
        }
    }

    /**
     * 分类列表
     * @return string
     */
    public function actionCateList()
    {
        $condition = $this->cate_id;
        $keywords = Yii::$app->request->get('keywords', '');
        if (!empty($keywords)) {
            $condition .= " AND (id = '{$keywords}' OR title LIKE '%{$keywords}%')";
        }
        $list = ArticleCategory::find()->where($condition);
        $this->view->title = '分类管理';
        return $this->render('cate-list', ['list' => $list, 'keywords' => $keywords]);
    }

    /**
     * 分类增加/修改
     * @return string|yii\web\Response
     */
    public function actionCateUpdate()
    {
        $item = new ArticleCategory();
        $id = intval(Yii::$app->request->get('id'));
        if (!empty($id)) {
            $item = ArticleCategory::findOne($id);
            if (empty($item)) {
                return $this->message('您要编辑的分类不存在', ['article/cate-list'], 'error');
            }
            $area = $item->find()->where($this->cate_id . " and id != $id and pid != $id ")->asArray()->all();
        } else {
            $area = ArticleCategory::find()->where($this->cate_id)->asArray()->all();
            $item = $item->loadDefaultValues();

        }
        if ($item->load(Yii::$app->request->post())) {
            if ($item->validate() && $item->save()) {
                $manager=new ManagerLog(); 
                 $manager->operate = "文章删除成功ID为".$id;
                 $result = $manager->save();
                return $this->message('更新成功', ['article/cate-list'], 'success');
            } else {
                return $this->message('更新失败', ['article/cate-list'], 'error');
            }
        }
        $tree = ArticleCategory::subtree($area, 0, 1);
        $list = array();
        foreach ($tree as $v) {
            $v['title'] = str_repeat(' - ', $v['lev']) . $v['title'];
            $list[] = $v;
        }
        return $this->render('cate-update', [
            'list' => $list,
            'item' => $item
        ]);
    }

    /**
     * 删除分类
     * @param $id
     * @return yii\web\Response
     * @throws \Throwable
     * @throws yii\db\StaleObjectException
     */
    public function actionCateDelete($id)
    {
        $item = ArticleCategory::findOne($id)->delete();
        if ($item > 0) {
            Yii::$app->getSession()->setFlash('success', '删除成功');
             $manager=new ManagerLog(); 
                 $manager->operate = "文章分类删除成功ID为".$id;
                 $result = $manager->save();
            return $this->redirect(['article/cate-list']);
        } else {
            Yii::$app->getSession()->setFlash('error', '删除失败');
            return $this->redirect(['article/cate-list']);
        }
    }

    /**
     * 幻灯片列表
     * @return string
     */
    public function actionSlideList()
    {
        $item = ArticleList::find()->where($this->slide_pic);
        $this->view->title = '幻灯片管理';
        return $this->render('/article/slide-list', ['list' => $item]);
    }

    /**
     * 首页欢迎页
     * @return string
     */
    public function actionIndexList()
    {
        $item = ArticleList::find()->where($this->index_pic)->orderBy('id');
        $this->view->title = '欢迎页管理';
        return $this->render('index-list', ['item' => $item]);
    }

    /**
     * 欢迎页新增/修改
     */
    public function actionIndexUpdate()
    {
        $item = new ArticleList();
        $id = intval(Yii::$app->request->get('id'));
        if (!empty($id)) {
            $item = ArticleList::findOne($id);
            if (empty($item)) {
                return $this->message('您要编辑的幻灯片不存在', ['/article/index-list'], 'error');
            }
        } else {
            $item = $item->loadDefaultValues();
        }
        if ($item->load(Yii::$app->request->post())) {
            $item->cid = 31;
            if ($item->save(false)) {
                $manager=new ManagerLog(); 
                 $manager->operate = "欢迎页新增/修改";
                $manager->params =base64_encode(serialize(Yii::$app->request->post()));
                 $result = $manager->save();
                return $this->message('更新成功', ['/article/index-list'], 'success');
            } else {
                return $this->message('更新失败', ['/article/index-list'], 'error');
            }
        }
        return $this->render('index-update', ['item' => $item]);
    }

    /**
     * 增加/修改幻灯片
     * @return string|yii\web\Response
     */
    public function actionSlideUpdate()
    {
        $item = new ArticleList();
        $id = intval(Yii::$app->request->get('id'));
        if (!empty($id)) {
            $item = ArticleList::findOne($id);
            if (empty($item)) {
                return $this->message('您要编辑的幻灯片不存在', ['article/slide-list'], 'error');
            }
        } else {
            $item = $item->loadDefaultValues();
        }
        if ($item->load(Yii::$app->request->post())) {
            if ($item->save(false)) {
                $manager=new ManagerLog(); 
                 $manager->operate = "欢迎页新增/修改幻灯片";
                $manager->params =base64_encode(serialize(Yii::$app->request->post()));
                 $result = $manager->save();
                return $this->message('更新成功', ['article/slide-list'], 'success');
            } else {
                return $this->message('更新失败', ['article/slide-list'], 'error');
            }
        }
        return $this->render('slide-update', ['item' => $item]);
    }

    /**
     * 删除幻灯片
     * @param $id
     * @return yii\web\Response
     * @throws \Throwable
     * @throws yii\db\StaleObjectException
     */
    public function actionSlideDelete($id)
    {
        $item = ArticleList::findOne($id)->delete();
        if ($item > 0) {
            Yii::$app->getSession()->setFlash('success', '删除成功');
            $manager=new ManagerLog(); 
             $manager->operate = "删除幻灯片".$id;
             $result = $manager->save();
            return $this->redirect(['article/slide-list']);
        } else {
            Yii::$app->getSession()->setFlash('error', '删除失败');
            return $this->redirect(['article/slide-list']);
        }
    }


}
