<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2018/1/22 HNDH Software Technology Co., Ltd.
 * @link http://www.dhsoft.cn
 */

namespace backend\controllers;


use common\models\Custom;
use common\models\ShopGoods;
use common\models\SmsLog;
use common\models\User;
use common\models\UserOrder;
use common\widgets\daterangepicker\DateRangePicker;
use Yii;
use common\models\ManagerLog;
class ShopController extends ControllerBase
{
    /**
     * 商品列表
     * @return string
     */
    public function actionList()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')]];
        $query = ShopGoods::find()->where('status = 2');
        $request = Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $con = "id = '{$keywords}' OR title LIKE '%{$keywords}%'  ";
            $query->andWhere($con);
        }

        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $conn = ['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])];
            $query->andWhere($conn);
        }
        $query->orderBy("id desc");
        $this->view->title = '商品列表';
        return $this->render('list', ['query' => $query, 'searchArr' => $searchArr]);
    }

    /**
     * 商品订单
     * @return string
     */
    public function actionOrder()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')], 'status' => ''];
        $query = UserOrder::find();
        $request = Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $conn = "uid = '{$keywords}' OR order_id LIKE '%{$keywords}%'  ";
            $query->andWhere($conn);
        }

        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $con = ['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])];
            $query->andWhere($con);
        }
        $type = $request->get('status', '');
        if (!empty($type)) {
            $searchArr['status'] = $type;
            $query->andWhere(['status' => $type]);
        }

        $query->orderBy("id desc");
        $total = $query->sum('price');
        $this->view->title = '商品订单';
        return $this->render('order', ['query' => $query, 'searchArr' => $searchArr, 'total' => $total]);
    }

    /**
     * 添加修改商品
     * @return string|\yii\web\Response
     */
    public function actionUpdate()
    {
        $item = new ShopGoods();
        $id = intval(Yii::$app->request->get('id'));
        if (!empty($id)) {
            $item = ShopGoods::findOne($id);
            if (empty($item)) {
                return $this->message('您要编辑订单不存在', ['/shop/list'], 'error');
            }
        } else {
            $item['created_at'] = time();
            $item = $item->loadDefaultValues();
        }
        if ($item->load(Yii::$app->request->post())) {
            if ($item->validate() && $item->save()) {
                 $manager=new ManagerLog(); 
                 if($id){
                    $manager->operate = "修改商品成功";


                 }else{
                    $manager->operate = "添加商品成功";

                 }
                 $manager->params =base64_encode(serialize(Yii::$app->request->post()));
             $result = $manager->save();
                return $this->message('更新成功', ['/shop/list'], 'success');
            } else {
                return $this->message('更新失败', ['/shop/list'], 'error');
            }
        }
        $this->view->title = '添加商品';
        return $this->render('update', ['item' => $item]);
    }
    //查询单个商品信息
    public function actionGoodsInfo(){
        $item = new ShopGoods();
    }
    /**
     * 删除商品
     * @return \yii\web\Response
     */
    public function actionDelete()
    {
        $id = Yii::$app->request->get('id');
        $model = ShopGoods::findOne($id);
        $model->status = 1; //改变状态
        if ($model->save()) {
             $manager=new ManagerLog(); 
             $manager->operate = "删除商品成功".$id;
             $result = $manager->save();
            return $this->message('删除成功!', ['/shop/list'], 'success');
        } else {
            return $this->message('删除失败!', ['/shop/list'], 'error');
        }
    }

    /**
     * 审核订单
     * @return \yii\web\Response
     */
    public function actionAgree()
    {
        $id = Yii::$app->request->get('id');
        $orderInfo = UserOrder::findOne(['id' => $id]);
        if (empty($orderInfo)) {
            return $this->message('参数错误!', ['/shop/order'], 'error');
        }
        if ($orderInfo->status == 2) {
            return $this->message('本单已经审核过，请勿重新审核!', ['/shop/order'], 'error');
        }
        $orderInfo->status = 2;
        $user = User::findOne(['uid' => $orderInfo['uid']]);
        $user->is_withdrawn = 1;
        if ($orderInfo->save() && $user->save()) {
              $manager=new ManagerLog(); 
             $manager->operate = "审核订单成功通过ID为".$id;
             $result = $manager->save();
            return $this->message('审核成功!', ['/shop/order'], 'success');
        } else {
            return $this->message('审核失败!' . current($orderInfo->getFirstErrors()) . current($user->getFirstErrors()), ['/shop/list'], 'error');
        }
    }

    /**
     * 拒绝订单
     * @return \yii\web\Response
     */
    public function actionReject()
    {
        $id = Yii::$app->request->get('id');
        $orderInfo = UserOrder::findOne(['id' => $id]);
        if (empty($orderInfo)) {
            return $this->message('参数错误!', ['/shop/order'], 'error');
        }
        if ($orderInfo->status != 1) {
            return $this->message('此单已经处理过,请勿重复处理!', ['/shop/order'], 'error');
        }
        $orderInfo->status = 3;
        $user = User::findOne(['uid' => $orderInfo['uid']]);
        $user->updateCounters(["credit2" => $orderInfo['price']]);
        $user->updateCounters(["credit7" => $orderInfo['price']]);
        if ($orderInfo->save()) {
            $manager=new ManagerLog(); 
             $manager->operate = "驳回订单成功通过ID为".$id;
             $result = $manager->save();
            return $this->message('成功驳回!', ['/shop/order'], 'success');
        } else {
            return $this->message('驳回失败!' . current($orderInfo->getFirstErrors()), ['/shop/list'], 'error');
        }
    }

    /**
     * 定制列表
     */
    public function actionCustom()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')]];
        $query = Custom::find();
        $request = Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $con = "id = '{$keywords}' or mobile like  '{$keywords}%'";
            $query->andWhere($con);
        }
        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $conn = ['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])];
            $query->andWhere($conn);
        }

        $query->orderBy("id desc");
        $this->view->title = '商品列表';
        return $this->render('custom-list', ['query' => $query, 'searchArr' => $searchArr]);
    }

    /**
     * 短信记录
     * @return string
     */
    public function actionSms()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')]];
        $query = SmsLog::find()->select(['id', 'uid', 'mobile', 'content', "FROM_UNIXTIME(created_at, '%Y-%m-%d %H:%i:%s') as riqi"]);
        $request = Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $con = "  mobile LIKE '%{$keywords}%'  ";
            $query->andWhere($con);
        }

        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $conn = ['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])];
            $query->andWhere($conn);
        }
        $time = date("Y-m-d", time());
        $query->andWhere(["FROM_UNIXTIME(created_at, '%Y-%m-%d')" => $time]);
        $query->orderBy("id desc");
        $this->view->title = '短信记录';
        return $this->render('sms-list', ['query' => $query, 'searchArr' => $searchArr]);
    }

}
