<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * @link http://www.dhsoft.cn
 */

namespace backend\controllers;


use common\models\User;
use common\models\Withdraw;
use common\widgets\daterangepicker\DateRangePicker;
use moonland\phpexcel\Excel;
use yii\db\Exception;
use common\models\ManagerLog;
class WithdrawController extends ControllerBase
{
    /**
     * 提现列表
     * @return string
     */
    public function actionList()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')], 'type' => ''];
        $query = Withdraw::find();
        $request = \Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $conn = "uid = '{$keywords}' OR order_id  LIKE '%{$keywords}%' ";
            $query->andWhere($conn);
        }

        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $query->andWhere(['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])]);
        }
        $type = $request->get('type', '');
        if (!empty($type)) {
            $searchArr['type'] = $type;
            $query->andWhere(['pay_type' => $type]);
        }
        if ($request->get('op') == 'export') {
            return Excel::export([
                'models' => $query->all(),
                'fileName' => '提现' . date('YmdHs') . '.xlsx',
                'headers' => ['gender' => '性别', 'created_at' => '注册时间', 'status' => '账户状态'],
                'columns' => ['uid:text:用户编号', 'order_id', 'bank_name', 'bank_card', 'withdraw_money', 'withdraw_percent', 'price', 'pay_type', ['attribute' => 'created_at', 'format' => ['date', 'php:Y-m-d H:i:s']],],
            ]);
        }
        $query->orderBy('id desc');
        $total = $query->sum('withdraw_money');
        $this->view->title = '提现列表';
        return $this->render('list', ['query' => $query, 'searchArr' => $searchArr, 'total' => $total]);
    }

    /**
     * 审核提现
     * @return \yii\web\Response
     * @throws Exception
     */
    public function actionUpdate()
    {
        $id = \Yii::$app->request->get('id');
        $withdraw_model = Withdraw::findOne(['id' => $id]);
        $transaction = \Yii::$app->db->beginTransaction();
        try {
            $withdraw_model->status = 2;
            $withdraw_model->updated_at = time();
            if ($withdraw_model->save()) {
                $transaction->commit();
                 $manager=new ManagerLog(); 
             $manager->operate = "提现审核成功ＩＤ为".$id;
             $result = $manager->save();
                return $this->message('审核成功', ['/withdraw/list'], 'success');
            } else {
                $transaction->rollBack();
                return $this->message('审核失败1', ['/withdraw/list'], 'error');
            }
        } catch (Exception $exception) {
            $transaction->rollBack();
            return $this->message('审核失败2' . $exception->getMessage(), ['/withdraw/list'], 'error');
        }
    }

    /**
     * 驳回提现
     * @return string|\yii\web\Response
     * @throws Exception
     */
    public function actionReject()
    {
        $id = \Yii::$app->request->get('id');
        $withdraw_model = Withdraw::findOne(['id' => $id]);
        $transaction = \Yii::$app->db->beginTransaction();
        try {
            if ($data = \Yii::$app->request->post('Withdraw')) {
                $user = User::findOne(['uid' => $withdraw_model['uid']]);
                if ($withdraw_model->pay_type == 2) {
                    $user->updateCounters(["credit2" => $withdraw_model->price]);
                } else {
                    $user->updateCounters(["credit" => $withdraw_model->price]);
                }
                $remark = $data['remark'] ?: '未知原因被驳回';
                $withdraw_model->remark = $remark;
                $withdraw_model->status = 3;
                if ($withdraw_model->save()) {
                    $transaction->commit();
                        $manager=new ManagerLog(); 
                        $manager->operate = "提现驳回成功ＩＤ为".$id."驳回原因是".$remark;
                        $result = $manager->save();
                    return $this->message('驳回成功', ['/withdraw/list'], 'success');
                } else {
                    $transaction->rollBack();
                    return $this->message('驳回失败', ['/withdraw/list'], 'error');
                }
            }
        } catch (Exception $exception) {
            $transaction->rollBack();
            return $this->message($exception->getMessage(), ['/withdraw/list'], 'error');
        }
        return $this->renderAjax('reject', ['model' => $withdraw_model]);
    }

    /**
     * 查询列表
     * @return string
     */
    public function actionUserList()
    {
        $searchArr = ['keywords' => '', 'date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')], 'type' => ''];
        $query = Withdraw::find();
        $request = \Yii::$app->request;
        $keywords = $request->get('keywords', '');
        $keywords = trim($keywords);
        $conn = $con = "";
        if (!empty($keywords)) {
            $searchArr['keywords'] = $keywords;
            $conn = "uid = '{$keywords}' and status=2";
            $query->andWhere($conn);
        }

        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $con = ['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])];
            $query->andWhere($con);
        }
        $type = $request->get('type', '');
        if (!empty($type)) {
            $searchArr['type'] = $type;
            $query->andWhere(['pay_type' => $type]);
        }
        if ($request->get('op') == 'export') {
            return Excel::export([
                'models' => $query->where($conn)->andWhere($con)->all(),
                'fileName' => '提现明细' . date('YmdHs') . '.xlsx',
                'headers' => ['gender' => '性别', 'created_at' => '注册时间', 'status' => '账户状态'],
                'columns' => ['uid:text:用户编号', 'order_id', 'bank_name', 'bank_card', 'withdraw_money', 'withdraw_percent', 'price', 'pay_type', ['attribute' => 'created_at', 'format' => ['date', 'php:Y-m-d H:i:s']],],
            ]);
        }

        $query->orderBy('id desc');
        $total = $query->sum('price');
        $this->view->title = '提现列表';
        return $this->render('user-list', ['query' => $query, 'searchArr' => $searchArr, 'total' => $total]);
    }

    /**
     * 同意全部
     * @return bool
     */
    public function actionUpdateAll()
    {
        $ids = \Yii::$app->request->get("keys");
        $ids = explode(',', $ids);
        foreach ($ids as $id) {
            $list = Withdraw::findOne(['id' => $id]);
            if ($list->status != 1) {
                return false;
            }
            $list->status = 2;
            $list->save();
        }
          $manager=new ManagerLog(); 
            $manager->operate = "同意全部提现";
            $result = $manager->save();
        return true;
    }

}
