<?php

namespace backend\models;

use yii\db\ActiveRecord;
use yii\web\IdentityInterface;

use Yii;


/**
 * This is the model class for table "{{%shops}}".
 *
 * @property integer $id
 * @property integer $uniacid
 * @property string $cid
 * @property string $username
 * @property string $password
 * @property string $title
 * @property string $model
 * @property string $disRatio
 * @property string $disRatioCount
 * @property string $disPoint
 * @property string $disCredit
 * @property string $disRatioChannel
 * @property string $disRatioCity
 * @property string $APM
 * @property string $disRatioPool
 * @property string $QQ
 * @property string $logo
 * @property string $description
 * @property string $shopCustomerNotice
 * @property string $birth
 * @property string $address
 * @property string $location
 * @property string $cname
 * @property string $tel
 * @property string $email
 * @property integer $care
 * @property integer $lookNum
 * @property integer $withType
 * @property integer $status
 * @property integer $displayorder
 * @property integer $isDel
 * @property integer $isHome
 * @property string $offlinePayDis
 * @property string $shopPeople
 * @property string $auth_key
 * @property string $access_token
 * @property string $shopPeopleDis
 * @property string $jsOffline
 * @property string $jsOfflineRate
 * @property integer $isMembers
 * @property string $memberRebate
 * @property integer $memberStatus
 * @property integer $memberDistance
 * @property integer $created_at
 * @property string $singleRemark
 * @property string $shopSelfConsumer
 * @property string $alipayName
 * @property integer $isCashback
 * @property string $cashbackInfo
 * @property string $mallMargin
 * @property integer $updatetime
 * @property integer $createtime
 */
class Shops extends ActiveRecord implements IdentityInterface
{
    const STATUS_DELETED = 0;
    const STATUS_ACTIVE = 1;
    // 接口认证过期时间
    const ACCESS_TOKEN_EXPIRE = 7200;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%shops}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['username', 'password', 'title', 'tel'], 'required'],
            [['id', 'status', 'shopPeople', 'shopuid', 'shop_type', 'created_at'], 'integer'],
            [['description', 'shopCustomerNotice'], 'string'],
            [['username', 'password', 'title', 'tel', 'email'], 'string', 'max' => 100],
            [['logo', 'birth', 'location', 'auth_key', 'access_token'], 'string', 'max' => 255],
            [['email'], 'email']
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'username' => '登录帐号',
            'password' => '密码',
            'title' => '商家名称',
            'model' => '商家类型',
            'shopuid' => '商家UID',
            'QQ' => '预留QQ',
            'logo' => '商家logo',
            'description' => '简介',
            'shopCustomerNotice' => '客户须知',
            'birth' => '地址',
            'address' => '详细地址',
            'location' => '经纬',
            'shop_type' => '加盟or开店',
            'cname' => '联系人',
            'tel' => '联系人电话',
            'email' => '邮箱',
            'care' => '被关注次数',
            'lookNum' => '浏览次数',
            'status' => '默认 1',
            'isDel' => '是否删除 0默认1删除',
            'offlinePayDis' => '线下支付折扣',
            'shopPeople' => '商家推荐人uid',
            'jsOffline' => '线下结算百分比',
            'jsOfflineRate' => '商家结算费率',
            'singleRemark' => '商家下单提示',
            'updated_at' => '最后一次更新时间',
            'created_at' => '创建时间',
        ];
    }

    /**
     * Finds user by username
     *
     * @param string $username
     * @return static|null
     */
    public static function findByUsername($username)
    {
        return static::findOne(['username' => $username, 'status' => self::STATUS_ACTIVE]);
    }


    /**
     * @inheritdoc
     */
    public static function findIdentity($id)
    {
        return static::findOne(['id' => $id, 'status' => self::STATUS_ACTIVE]);
    }

    /**
     * @inheritdoc
     */
    public function getId()
    {
        return $this->getPrimaryKey();
    }

    /**
     * @inheritdoc
     */
    public function getAuthKey()
    {
        return $this->auth_key;
    }

    /**
     * @inheritdoc
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        $token = json_decode(base64_decode($token), true);
        if (!empty($token['uid']) && !empty($token['timestamp']) && ($token['timestamp'] + self::ACCESS_TOKEN_EXPIRE) >= time()) {
            $user = static::findIdentity($token['uid']);
            if (!empty($user) && $token['sign'] === md5($token['uid'] . $token['timestamp'] . $user->access_token)) {
                return $user;
            }
        }
        return null;
    }

    /**
     * @inheritdoc
     */
    public function validateAuthKey($authKey)
    {
        return $this->getAuthKey() === $authKey;
    }


    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return bool if password provided is valid for current user
     */
    public function validatePassword($password)
    {
        return \Yii::$app->security->validatePassword($password, $this->password);
    }

    /**
     * 根据推荐人查找店铺
     * @param $id
     * @param $page
     * @param $limit
     * @return array|\yii\db\ActiveRecord[]
     */
    public function findByPople($id, $page = 1, $limit = 10)
    {
        return Shops::find()->select(['id', 'title', 'address', 'turnover'])->where(['shopPeople' => $id])->offset(($page - 1) * $limit)->limit($limit)->asArray()->all();
    }

    /**
     * 获取两点之间的距离
     * @param $latitude1
     * @param $longitude1
     * @param $latitude2
     * @param $longitude2
     * @return string
     */
    public function getDistanceBetweenPointsNew($latitude1, $longitude1, $latitude2, $longitude2)
    {
        $theta = $longitude1 - $longitude2;
        $miles = (sin(deg2rad($latitude1)) * sin(deg2rad($latitude2))) + (cos(deg2rad($latitude1)) * cos(deg2rad($latitude2)) * cos(deg2rad($theta)));
        $miles = acos($miles);
        $miles = rad2deg($miles);
        $miles = $miles * 60 * 1.1515;
//        $feet = $miles * 5280;
//        $yards = $feet / 3;
        $kilometers = $miles * 1.609344;
        $meters = $kilometers * 1000;
        return round($meters) . '米';
    }


    /**
     * 查询附近的商家
     * @param $squares
     * @param bool $isrecom
     * @return array|Shops[]|ActiveRecord[]
     */
    public function findNearbyShop($squares, $isrecom = false)
    {
//         return $info = Shops::find()->where(['and',['between' , 'lat1' , $squares['right-bottom']['lat'] , $squares['left-top']['lat']],['between' , 'lng' , $squares['right-bottom']['lng'],$squares['left-top']['lng'] ]])->asArray()->all();
        $query = Shops::find()->select(['id', 'title', 'tel', 'logo', 'address', 'lat', 'lng'])->andWhere(['and', ['between', 'lat', $squares['right-bottom']['lat'], $squares['left-top']['lat']], ['between', 'lng', $squares['left-top']['lng'], $squares['right-bottom']['lng']]])->asArray()->all();
        if ($isrecom == true) {
            $query = Shops::find()->select(['id', 'title', 'tel', 'logo', 'address', 'lat', 'lng'])->andWhere(['and', ['between', 'lat', $squares['right-bottom']['lat'], $squares['left-top']['lat']], ['between', 'lng', $squares['left-top']['lng'], $squares['right-bottom']['lng']]])->andWhere(['isrecom' => 1])->asArray()->all();
        }
        return $query;
    }

    public function findByShopInfo($info, $page = 1, $limit = 5)
    {
        return Shops::find()->select(['id', 'title', 'address', 'turnover'])->andwhere("province LIKE '%{$info}%' OR city LIKE '%{$info}%' OR county LIKE '%{$info}%'")->offset(($page - 1) * $limit)->limit($limit)->asArray()->all();
    }

    /**
     * 生成access_token
     */
    public function generateAccessToken()
    {
        $this->access_token = Yii::$app->security->generateRandomString();
        $this->save();
    }

    /**
     * Generates "remember me" authentication key
     */
    public function generateAuthKey()
    {
        $this->auth_key = Yii::$app->security->generateRandomString();
    }

}
