<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['game-room/list'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control']); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['game-room/list']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
                        <?= Html::submitButton('导出房间列表', ['class' => 'btn btn-primary pull-right', 'name' => 'op', 'value' => 'export']); ?>
                    </div>
                </div>
                <?= Html::endForm() ?>
            </div>
        </div>

        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 10,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'owner_uid',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'type',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'mode',
                        'enableSorting' => true,
                    ],
                    [
                        'label' => '房间人数',
                        'attribute' => 'num',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'cur_round',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'is_playing',
                        'enableSorting' => true,
                    ],
                    [
                        'label' => '状态',
                        'attribute' => 'status',
                        'enableSorting' => true,
                        'format' => 'html',
                        'value' => function ($model) {
                            return $model->status == 0 ? '<span class="badge bg-green">新建</span>' : '<span class="badge bg-red">结束</span>';
                        }
                    ],
                    [
                        'attribute' => 'created_at',
                        'format' => ['date', 'php:Y-m-d H:i:s'],
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'updated_at',
                        'format' => ['date', 'php:Y-m-d H:i:s'],
                        'enableSorting' => true,
                    ],
                    [
                        'class' => MyActionColumn::class,
                        'template' => '{score}&nbsp;&nbsp;{channel}',
                        'headerOptions' => ['width' => '80'],
                        'buttons' => [
                            'score' => function ($url) {
                                return Html::a('<span class="glyphicon glyphicon-yen"></span>', $url, ['title' => '计分详情']);
                            },
                            'channel' => function ($url) {
                                return Html::a('<span class="glyphicon glyphicon-menu-hamburger"></span>', $url, ['title' => '房间详情']);
                            },
                        ],
                    ],
                ]
            ]);
            ?>
        </div>
    </div>
</div>


