<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\helpers\Utils;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['shops/list'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control', 'placeholder' => "用户id、昵称、姓名、手机号"]); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['/shops/list']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
<!--                        < ?= Html::submitButton('导出会员列表', ['class' => 'btn btn-primary pull-right', 'name' => 'op', 'value' => 'export']); ?>-->
                    </div>
                </div>
                <?= Html::endForm() ?>
            </div>

        </div>
        <div class="box-header clearfix no-border">
            <a href="<?= Url::toRoute(['shop/update']) ?>" class="btn btn-primary pull-left">
                <i class="fa fa-plus"></i> 添加商品
            </a>
        </div>

        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 10,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'title',
                    ],
                    [
                        'attribute' => 'price',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'imgs',
                        'format' => 'raw',
                        'value' => function ($model) {
                            return Html::a(Html::img(Utils::toMedia($model->imgs),
                                ['class' => 'img-rectangle',
                                    'height' => 50, 'width' => 100]
                            ), ['/article/big-pic', 'id' => $model->imgs], ['title' => '放大图片', 'data-toggle' => 'modal', 'data-target' => '#ajaxModal']) ?: '';
                        },
                    ],
                    [
                        'class' => MyActionColumn::class,
                        'template' => '{update}&nbsp;&nbsp;{delete}',
                        'headerOptions' => ['width' => '80'],
                    ],
                ]
            ]);
            ?>
        </div>
    </div>
</div>


