<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */
/** @var string $total */
/**
 * @param int
 * @return int
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\helpers\MyHtml;
use common\models\Config;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['shop/order'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control', 'placeholder' => "用户id、订单号"]); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">类型</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::checkboxList('status', $searchArr['status'], Config::getConfig('QUERY_STATUS'), ['item' => [MyHtml::className(), 'checkboxListItem']]); ?>
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['/shop/order']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
<!--                        < ?= Html::submitButton('导出会员信息', ['class' => 'btn btn-primary pull-right', 'name' => 'op', 'value' => 'export']); ?>-->
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">统计</label>
                    <div class="col-xs-12 col-sm-8 col-md-3 col-lg-3">
                        <div class="input-group">
                            <span class="input-group-addon">实缴金额</span>
                            <input name="config[exchangevol][2]" value="<?=
                            $total ?>" class="form-control" placeholder="请输入整数" disabled>
                            <span class="input-group-addon">元</span>
                        </div>
                    </div>
                </div>

                <?= Html::endForm() ?>
            </div>
        </div>


        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 10,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'uid',
                        'enableSorting' => true,
                    ],
                    [
                        'label' => '姓名',
                        'value' => function ($model) {
                            $str = \common\models\User::findNameByid($model->uid);
                            return $str['realname'];
                        },
                    ],
                    [
                        'label' => '电话',
                        'value' => function ($model) {
                            $str = \common\models\User::findNameByid($model->uid);
                            return $str['mobile'];
                        },
                    ],
                    [
                        'attribute' => 'order_id',
                    ],
                    [
                        'attribute' => 'title',
                    ],
                    [
                        'attribute' => 'price',
                    ],
                    [
                        'attribute' => 'status',
                        'value' => function ($model) {
                            $str = '';
                            if ($model->status == 1) {
                                $str = '待审核';
                            } elseif ($model->status == 2) {
                                $str = '已审核';
                            } elseif ($model->status == 3) {
                                $str = '已驳回';
                            }
                            return $str;
                        },
                    ],
                    [
                        'attribute' => 'created_at',
                        'format' => ['date', 'php:Y-m-d H:i:s'],
                        'enableSorting' => true,
                    ],
                    [
                        'class' => MyActionColumn::class,
                        'headerOptions' => ['width' => '80'],
                        'template' => '{reject}&nbsp;&nbsp;{agree}',
                        'buttons' => [
                            'agree' => function ($url, $model) {
                                return $model->status == 1 ?
                                    Html::a('<span class="glyphicon glyphicon-ok-circle"></span>', $url, ['title' => '审核', 'onclick' => "if(!confirm('请确认审核成功吗？')) return false;"]) : '';
                            },
                            'reject' => function ($url, $model) {
                                return $model->status == 1 ?
                                    Html::a('<span class="glyphicon glyphicon-remove-circle"></span>', $url, ['title' => '审核驳回', 'onclick' => "if(!confirm('请确认驳回此单吗？')) return false;"]) : '';
                            },
                        ],
                    ],
                ]
            ]);
            ?>
        </div>
    </div>
</div>


