<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['shops/list'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control', 'placeholder' => "用户id、昵称、姓名、手机号"]); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>

                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['/shops/list']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
                        <?= Html::submitButton('导出会员列表', ['class' => 'btn btn-primary pull-right', 'name' => 'op', 'value' => 'export']); ?>
                    </div>
                </div>
                <?= Html::endForm() ?>
            </div>
        </div>

        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 10,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'shopuid',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'username',
                        'enableSorting' => true,
                        'value' => function ($model) {
                            $str = '';
                            $str .= empty($model->username) ? '未完善' : $model->username;
                            return $str;
                        }
                    ],
                    [
                        'attribute' => 'shop_type',
                        'enableSorting' => true,
                        'value' => function ($model) {
                            $str = '';
                            $str .= empty($model->shop_type) ? '加盟' : "开店";
                            return $str;
                        }
                    ],
                    [
                        'attribute' => 'title',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'QQ',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'birth',
                        'enableSorting' => true,
                        'value' => function ($model) {
                            $arr = json_decode($model->birth, true);
                            $str = $arr['province'] . $arr['city'] . $arr['county'];
                            return $str;
                        },
                    ],
                    [
                        'attribute' => 'address',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'tel',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'email',
                        'enableSorting' => true,
//                        'value'=>function($model){
//                            if ($model->gender == '1'){
//                             $str = '男';
//                            }else if ($model->gender == '0'){
//                                $str = '女';
//                            }else{
//                                $str = '未知';
//                            }
//                            return $str;
//                        },
                    ],
                    [
                        'attribute' => 'care',
                        'enableSorting' => true,
                    ],
                    [
                        'attribute' => 'lookNum',
//                        'format' => ['date','php:Y-m-d H:i:s'],
                        'enableSorting' => true,
                    ],
//                    [
//                        'attribute' => 'status',
//                        'enableSorting' => true,
//                        'label' => '账户状态',
//                        'format' =>'raw',
//                        'value' => function ($model) {
//                                return $model->status ==0 ?'<span class="badge bg-green">正常</span>':'<span class="badge bg-red">冻结</span>';
//                        }
//                    ],
                    [
                        'class' => MyActionColumn::class,
                        'template' => '{update}&nbsp;&nbsp;{delete}',
                        'headerOptions' => ['width' => '80'],
                        'buttons' => [
                            'update' => function ($url) {
                                return Html::a('<span class=" glyphicon glyphicon-pencil"></span>', $url, ['title' => '修改商家', 'data-toggle' => 'modal', 'data-target' => '#ajaxModal']);
                            },
                        ],

                    ],
                ]
            ]);
            ?>
        </div>
    </div>
</div>


