<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['user/proxy'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control', 'placeholder' => "UID、昵称、姓名"]); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['user/proxy']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
                        <!--                        < ?= Html::submitButton('导出会员列表', ['class' => 'btn btn-primary pull-right','name'=>'op', 'value'=>'export']); ?>-->
                    </div>
                </div>
                <?= Html::endForm() ?>
            </div>
        </div>
        <div class="box-header clearfix no-border">
            <a href="<?= Url::toRoute(['user/report-update']) ?>" class="btn btn-primary pull-left">
                <i class="fa fa-plus"></i> 添加销售中心
            </a>
        </div>
        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 20,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                        'format' => 'raw',
                    ],
//                    [
//                        'attribute' => 'uid',
//                        'enableSorting' => true,
//                        'format' => 'raw',
//                    ],
                    [
                        'attribute' => 'name',
                    ],
                    [
                        'attribute' => 'org_name',
                    ],

                    [
                        'attribute' => 'mobile',
                    ],

                    [
                        'attribute' => 'proxy_lv',
                        'value' => function ($model) {
                            if ($model->proxy_lv == 1) {
                                $str = '省级';
                            } elseif ($model->proxy_lv == 2) {
                                $str = '市级';
                            } else {
                                $str = '区级';
                            }
                            return $str;
                        }
                    ],
                     [
                        'attribute' => 'type',
                        'value' => function ($model) {
                            if ($model->type == 1) {
                                $str = '销售中心';
                            } elseif ($model->type == 2) {
                                $str = '地区代理';
                            } else {
                                $str = '借款销售中心';
                            }
                            return $str;
                        }
                    ],

                    [
                        'attribute' => 'proxy_address',
                    ],
                    [
                        'attribute' => 'status',
                        'value' => function ($model) {
                            if ($model->status == 1) {
                                $str = '待审核';
                            } elseif ($model->status == 2) {
                                $str = '已审核';
                            } else {
                                $str = '已驳回';
                            }
                            return $str;
                        }
                    ],
                    [
                        'label' => '注册时间',
                        'attribute' => 'created_at',
                        'format' => ['date', 'php:Y-m-d H:i:s'],
                    ],
                    [
                        'class' => MyActionColumn::class,
                        'template' => '{proxy-edit}{proxy-delete}',
                        'headerOptions' => ['width' => '8'],
                        'buttons' => [
                            'proxy-edit' => function ($url, $model, $key) {
                                return Html::a('修改', Url::toRoute(['user/report-update', 'id' => $model->id]));
                            },
                             'proxy-delete' => function ($url, $model, $key) {
                                return Html::a('删除', Url::toRoute(['user/proxy-delete', 'id' => $model->id]), ['onclick' => "return confirm('确定删除吗？');return false;"]);

                            },

                        ],
                    ],
                ]
            ]);
            ?>
        </div>
    </div>
</div>


