<?php

/**
 * @var $this yii\web\View
 * @var $query yii\db\ActiveQuery
 * @var $searchArr array
 */

use backend\widgets\grid\MyActionColumn;
use backend\widgets\grid\MyGridView;
use common\widgets\daterangepicker\DateRangePicker;
use yii\data\ActiveDataProvider;
use yii\helpers\Html;
use yii\helpers\Url;

?>
<div class="nav-tabs-custom">
    <?= $this->render('_tabs'); ?>
    <div class="tab-content">
        <div class="box box-success">
            <div class="box-header with-border">
                <div class="box-tools pull-right">
                    <button type="button" class="btn btn-box-tool" data-widget="collapse"><i class="fa fa-minus"></i>
                    </button>
                </div>
            </div>
            <div class="box-body">
                <?= Html::beginForm(['user/report-manage'], 'get', ['class' => 'form-horizontal']) ?>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">关键词</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::textInput('keywords', $searchArr['keywords'], ['class' => 'form-control', 'placeholder' => "UID、昵称、姓名"]); ?>
                        <div class="help-block">请输入关键字</div>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label">时间</label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= DateRangePicker::widget([
                            'name' => 'date',
                            'clientOptions' => [
                                'startDate' => $searchArr['date']['start'],
                                'endDate' => $searchArr['date']['end'],

                            ],
                            'clientEvents' => [],
                        ]) ?>
                    </div>
                </div>
                <div class="form-group">
                    <label class="col-xs-12 col-sm-3 col-md-2 col-lg-1 control-label"></label>
                    <div class="col-xs-12 col-sm-8 col-md-8 col-lg-6">
                        <?= Html::submitButton('提交', ['class' => 'btn btn-success']); ?>
                        <a href="<?= Url::toRoute(['user/report-manage']) ?>">
                            <div class="btn btn-default"><i class="glyphicon glyphicon-leaf"></i> 清除筛选</div>
                        </a>
                        <!--                        < ?= Html::submitButton('导出会员列表', ['class' => 'btn btn-primary pull-right','name'=>'op', 'value'=>'export']); ?>-->
                    </div>
                </div>
                <?= Html::endForm() ?>
            </div>
        </div>
        <div class="tab-pane active">
            <?php
            $dataProvider = new ActiveDataProvider([
                'query' => $query,
                'pagination' => [
                    'pageSize' => 10,
                ],
            ]);
            $arr = $query->all();
            echo MyGridView::widget([
                'dataProvider' => $dataProvider,
                'columns' => [
                    [
                        'attribute' => 'id',
                        'enableSorting' => true,
                        'format' => 'raw',
                    ],
                    [
                        'attribute' => 'uid',
                        'enableSorting' => true,
                        'format' => 'raw',
                    ],
                    [
                        'attribute' => 'name',
                    ],
                    [
                        'attribute' => 'mobile',
                    ],
                    [
                        'attribute' => 'proxy_address',
                    ],
                    [
                        'attribute' => 'address',
                    ],
                    [
                        'attribute' => 'status',
                        'value' => function ($model) {
                            if ($model->status == 1) {
                                $str = '待审核';
                            } elseif ($model->status == 2) {
                                $str = '已审核';
                            } else {
                                $str = '已驳回';
                            }
                            return $str;
                        }
                    ],
                    [
                        'label' => '注册时间',
                        'attribute' => 'created_at',
                        'format' => ['date', 'php:Y-m-d H:i:s'],
                    ],
                    [
                        'class' => MyActionColumn::class,
                        'template' => '{role-del}&nbsp;&nbsp;{delete}',
                        'buttons' => [
                            'role-del' => function ($url, $model, $key) {
                                return ($model->status == 1) ? Html::a('同意', Url::toRoute(['user/proxy-update', 'id' => $model->id]), ['class' => 'btn btn-sm btn-warning', 'onclick' => "return confirm('确认同意该订单吗？');return false;"]) : '';
                            },
                            'delete' => function ($url, $model, $key) {
                                return ($model->status == 1) ? Html::a('拒绝', Url::toRoute(['user/proxy-delete', 'id' => $model->id]), ['class' => 'btn btn-sm btn-warning', 'title' => '驳回原因', 'data-toggle' => 'modal', 'data-target' => '#ajaxModal']) : '';
                            }
                        ],
                    ]
                ]
            ]);
            ?>
        </div>
    </div>
</div>


