<?php

namespace common\helpers;

use common\models\Config;
use yii\db\Exception;
use yii\httpclient\Client;
use yii\web\Response;

class IntegralPay
{
    public $pay_data;
    protected $sign;
    protected $key = '';
    const API_URL = 'http://tanhui2.dhcc.wang/api/w2/user/add-integral';

    //初始化
    public function __construct($data)
    {
        $this->key = Config::getConfig('SYSTEM_API_SECRET');
        $this->pay_data = $this->initData($data);
    }

    protected function initData($data)
    {
        if (empty($data['uid'])) {
            throw new Exception('参数错误,请检查用户信息');
        }
        $this->pay_data['uid'] = $data['uid'];
        if (empty($data['integral']) || $data['integral'] <= 0) {
            throw new Exception('增加积分错误，请核实');
        }
        $this->pay_data['integral'] = $data['integral'];

        if (empty(self::API_URL)) {
            throw  new Exception('接口尚未配置');
        }
        $this->pay_data['nonce_str'] = mt_rand(time(), time() + $this->rand(1, 10000));
        return $this->pay_data;
    }

    //发送请求
    public function pay()
    {
        $this->pay_data['sign'] = $this->getSign();
        $client = new  Client();
        $response = $client->createRequest()
            ->setMethod('post')
            ->setUrl(self::API_URL)
            ->setData($this->pay_data)
            ->send();
        if ($response->isOk) {
            return json_decode($response->content);
        } else {
            throw new Exception('请求失败');
        }
    }

    //获取签名
    public function getSign()
    {
        ksort($this->pay_data);
        $str = '';
        if (!empty($this->pay_data)) {
            foreach ($this->pay_data as $k => $v) {
                if ("" != $v && "sign" != $k) {
                    $str .= $k . "=" . $v . "&";
                }
            }
            $str .= 'key=' . $this->key;
            $sign = strtoupper(md5($str));
        } else {
            $sign = '';
        }
        return $sign;
    }

    protected function rand($min, $max)
    {
        mt_srand((double)microtime() * 1000000);
        return mt_rand($min, $max);
    }

    public function responseJson($code = 0, $data = [], $msg = '')
    {
        \Yii::$app->response->format = Response::FORMAT_JSON;
        $data = ['code' => $code, 'data' => $data, 'msg' => $msg];
        return $data;
    }

    /**
     * 检查签名是否正确
     * @param $params
     * @return bool
     * @throws Exception
     */
    public function checkSign($params)
    {
        if (empty($params) || empty($params['sign'])) {
            throw new Exception('签名不存在，请联系管理员');
        }
        $buff = "";
        ksort($params);
        foreach ($params as $k => $v) {
            if ($k != 'sign' && $v != '' && !is_array($v)) {
                $buff .= $k . '=' . $v . '&';
            }
        }
        $buff = trim($buff, '&');
        if (empty($this->key)) {
            throw new Exception('通讯密匙尚未设置，请联系管理员');
        }
        $buff .= '&key=' . $this->key;
        return strtoupper(md5($buff)) === $params['sign'];
    }

}
