<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/8/25 9:13
 */

namespace common\helpers;

use common\models\Config;
use common\models\SmsLog;
use yii\httpclient\Client;
use yii\httpclient\Response;

class Sms
{
    const API_URL = 'http://120.24.238.58:8888/sms.aspx?action=send';
//    const API_URL = 'https://smssh1.253.com/msg/send/json';

    /**
     * @param $mobile
     * @param string $content 短信内容
     * @param string $type 短信发送类型 备注
     * @return bool|string
     */
    public static function send($mobile, $content = '', $type = 'other')
    {
        if (empty($mobile)) {
        	
            return '短信发送失败: 手机号不能为空';
        }
        if (!preg_match('/^1[0-9]{10}$/', $mobile)) {
            return '短信发送失败: 手机号不正确';
        }
        if (empty($content)) {
            return '短信发送失败: 短信内容不能为空';
        }

        $smsLog = new SmsLog();
        $smsLog->mobile = $mobile;
        $smsLog->content = $content;
        $smsLog->type = $type;

        $userid = Config::getConfig('MESSAGE_API_USERID');
        $account = Config::getConfig('MESSAGE_API_ACCOUNT');
        $password = Config::getConfig('MESSAGE_API_PWD');
        if (empty($userid) || empty($account) || empty($password)) {
            $smsLog->status = 0;
            $smsLog->result = '短信发送失败: 请联系管理员配置通讯密匙' . $content;
        } else {
            $client = new Client();
            /** @var Response $response */
            $response = $client->post(self::API_URL, [
                "userid" => $userid,
                "account" => $account,
                "password" => $password,
                "mobile" => $mobile, //string	手机号码每次只能提交1个号码
                "content" => $content, //string	短信内容。
            ])->send();
//            $response = $client->post(self::API_URL, [
//                "account" => $userid,
//                "password" => $password,
//                "phone" => $mobile, //string	手机号码每次只能提交1个号码
//                "msg" => urlencode($content), //string	短信内容。
//                "report" => true,
//            ])->send();
            if (!$response->isOk) {
                $smsLog->status = 0;
                $smsLog->result = '短信发送失败: 网络请求错误';
            } else {
                if ($response->content == 0) {
                    $smsLog->status = 1;
                    $smsLog->result = '短信发送成功';
                } else {
                    $smsLog->status = 0;
                    $smsLog->result = self::errorCode($response->content);
                }
            }
        }

        if (!$smsLog->validate()) {
            return current($smsLog->getFirstErrors());
        } else {
            $result = $smsLog->save();
            if ($result !== true) {
                return '短信发送失败: 短信记录保存失败';
            }
        }

        if ($smsLog->status === 1) {
            return true;
        } else {
            return $smsLog->result;
        }
    }

    /**
     * @param int $code
     * @return string
     */
    private static function errorCode($code = 0)
    {
        $code = intval($code);
        $codeMsg = [
            '30' => '密码错误',
            '40' => '账号不存在',
            '41' => '余额不足',
            '42' => '帐号过期',
            '43' => 'IP地址限制',
            '50' => '内容含有敏感词',
            '51' => '手机号码不正确',
        ];
        return isset($codeMsg[$code]) ? '短信发送失败: ' . $codeMsg[$code] : '短信发送失败: 短信接口返回未知错误';
    }
}
