<?php

namespace common\helpers;


use yii\helpers\ArrayHelper;

class Utils
{
    /**
     * 普通URl格式化为Url::to()的参数
     * @param string $url site/index?type=save
     * @return array
     * @see Url::to()
     */
    public static function parseUrl($url)
    {
        $data = [];
        $arr = parse_url($url);
        $data[] = $arr['path'];
        if (!empty($arr['query'])) {
            parse_str($arr['query'], $query);
            $data = ArrayHelper::merge($data, $query);
        }
        return $data;
    }

    /**
     * 将特殊字符转换为 HTML 实体
     * @param string|array $var HTML字符
     * @return array|mixed
     */
    public static function iHtmlSpecialChars($var)
    {
        if (is_array($var)) {
            foreach ($var as $key => $value) {
                $var[htmlspecialchars($key)] = self::iHtmlSpecialChars($value);
            }
        } else {
            $var = str_replace('&amp;', '&', htmlspecialchars($var, ENT_QUOTES));
        }
        return $var;
    }

    /**
     * 生成随机字符串
     * @param int $length 字符串长度
     * @param bool $numeric true表示纯数字
     * @return string
     */
    public static function random($length, $numeric = FALSE)
    {
        $seed = base_convert(md5(microtime() . $_SERVER['DOCUMENT_ROOT']), 16, $numeric ? 10 : 35);
        $seed = $numeric ? (str_replace('0', '', $seed) . '012340567890') : ($seed . 'zZ' . strtoupper($seed));
        if ($numeric) {
            $hash = '';
        } else {
            $hash = chr(rand(1, 26) + rand(0, 1) * 32 + 64);
            $length--;
        }
        $max = strlen($seed) - 1;
        for ($i = 0; $i < $length; $i++) {
            $hash .= $seed{mt_rand(0, $max)};
        }
        return $hash;
    }

    /**
     * 数组转xml
     * @param array $arr
     * @param int $level
     * @return mixed|string
     */
    public static function array2xml($arr, $level = 1)
    {
        $s = $level == 1 ? "<xml>" : '';
        foreach ($arr as $tagName => $value) {
            if (is_numeric($tagName)) {
                $tagName = $value['TagName'];
                unset($value['TagName']);
            }
            if (!is_array($value)) {
                $s .= "<{$tagName}>" . (!is_numeric($value) ? '<![CDATA[' : '') . $value . (!is_numeric($value) ? ']]>' : '') . "</{$tagName}>";
            } else {
                $s .= "<{$tagName}>" . self::array2xml($value, $level + 1) . "</{$tagName}>";
            }
        }
        $s = preg_replace("/([\x01-\x08\x0b-\x0c\x0e-\x1f])+/", ' ', $s);
        return $level == 1 ? $s . "</xml>" : $s;
    }

    /**
     * base64图片解码上传图片
     * @param $date
     * @return string
     * @throws \yii\db\Exception
     */
    public static function base64pic($date)
    {
        //项目绝对路径
        $url = str_replace('\\', '/', \Yii::getAlias('@public'));

        if (preg_match('/^(data:\s*image\/(\w+);base64,)/', $date, $result)) {
            $type = $result[2];
            $img = base64_decode(str_replace($result[1], '', $date));
            $new_file = $url . '/uploads/image/' . date('Ym', time()) . '/' . date('d', time()) . '/';
            if (!file_exists($new_file)) {
                mkdir($new_file, 0777, true);
            }
            $info_file = date("YmdHis") . '_' . rand(10000, 99999) . '.' . "{$type}";
            $new_file = $new_file . $info_file;
            //数据库存储地址
            $db_file = '/uploads/image/' . date('Ym', time()) . '/' . date('d', time()) . '/' . $info_file;
            if ($file = file_put_contents($new_file, $img)) {
                return $db_file;
            } else {
                throw new \yii\db\Exception('文件保存失败1');
            }
        } else {
            throw new \yii\db\Exception('文件保存失败2');
        }
    }

    /**
     * 递归生成目录树
     * @param array $data
     * @param int $pid
     * @param string $idName
     * @param string $pidName
     * @param string $sonName
     * @return array
     */
    public static function tree($data = [], $pid = 0, $idName = "id", $pidName = 'pid', $sonName = 'son')
    {
        $arr = [];
        foreach ($data as $v) {
            if ($v[$pidName] == $pid) {
                $v[$sonName] = self::tree($data, $v[$idName], $idName, $pidName);
                $arr[] = $v;
            }
        }
        return $arr;
    }

    /**
     * 输出图像方法
     * @param $src
     * @return string
     */
    public static function toMedia($src)
    {
        $url = \Yii::$app->request->hostInfo;
        $http = strtolower($src);
        if (strpos($http, 'http://') !== false || strpos($http, 'https://') !== false) {
            return $src;
        }
        if (substr($src, 0, 1) == '/') {
            $src = $url . $src;
        } else {
            $src = $url . '/' . $src;
        }
        return $src;
    }


    /**
     * 获取用户真实IP
     * @return array|false|string
     */
    public static function getIp()
    {
        $ip = $_SERVER['REMOTE_ADDR'];
        if (isset($_SERVER['HTTP_CDN_SRC_IP'])) {
            $ip = $_SERVER['HTTP_CDN_SRC_IP'];
        } elseif (isset($_SERVER['HTTP_CLIENT_IP']) && preg_match('/^([0-9]{1,3}\.){3}[0-9]{1,3}$/', $_SERVER['HTTP_CLIENT_IP'])) {
            $ip = $_SERVER['HTTP_CLIENT_IP'];
        } elseif (isset($_SERVER['HTTP_X_FORWARDED_FOR']) && preg_match_all('#\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}#s', $_SERVER['HTTP_X_FORWARDED_FOR'], $matches)) {
            foreach ($matches[0] AS $xip) {
                if (!preg_match('#^(10|172\.16|192\.168)\.#', $xip)) {
                    $ip = $xip;
                    break;
                }
            }
        }
        return $ip;
    }

    /**
     * 生成订单号
     * @param string $prefix
     * @param int $id 唯一数字
     * @param int $length
     * @return string
     */
    public static function genderOrderId($id, $prefix = 'order', $length = 5)
    {
        $id = substr($id, -$length);
        return $prefix . date('ymd') . str_pad($id, 5, 0, STR_PAD_LEFT);
    }


    /**
     * 字符串中img中加域名
     * @param string $content
     * @return mixed|string
     */
    public static function get_img_thumb_url($content = "")
    {
        $suffix = \Yii::$app->request->hostInfo;
        $pregRule = "/<[img|IMG].*?src=[\'|\"](.*?(?:[\.jpg|\.jpeg|\.png|\.gif|\.bmp]))[\'|\"].*?[\/]?>/";
        $content = preg_replace($pregRule, '<img src="' . $suffix . '${1}" style="max-width:100%">', $content);
        return $content;
    }


}
