<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/9/28 20:58
 */

namespace common\models;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;


/**
 * 公告模型
 * @property int $id [int(10) unsigned]  公告id
 * @property string $title [varchar(255)]  标题
 * @property string $thumb [varchar(100)]  图片
 * @property string $remark 描述
 * @property string $content 内容
 * @property string $heat 热度状态
 * @property bool $status [tinyint(1) unsigned]  状态，1启用，9禁用
 * @property bool $type [tinyint(1) unsigned]  类型，1系统，2游戏
 * @property int $created_at [int(11) unsigned]
 * @property int $updated_at [int(11) unsigned]
 */
class Announcement extends ActiveRecord
{
    public function rules()
    {
        return [
            [['title'], 'required', 'message' => '标题不能为空'],
            [['remark'], 'required', 'message' => '描述不能为空'],
            //[['content'],'required','message'=>'内容不能为空'],
            [['type', 'status', 'content', 'thumb', 'heat', 'created_at', 'updated_at'], 'safe'],
        ];
    }

    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'title' => '公告标题',
            'remark' => '公告描述',
            'content' => '公告内容',
            'type' => '公告类型',
            'created_at' => '创建时间',
            'updated_at' => '更新时间',
            'heat' => '热度状态',
            'status' => '状态',
        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at',
            ],
        ];
    }

    /**
     * 获取对应标题公告
     * @param $type
     * @param $title
     * @return array|Announcement|null|ActiveRecord
     */
    public static function getTitle($title, $type)
    {
        return self::find()->select(['id', 'title', 'remark', 'content', 'created_at', 'updated_at'])->where("type = $type AND title = '{$title}' AND status = 1")->asArray()->one();
    }

    /**
     * 获取帮助支持公告
     * @param $page
     * @return array|Announcement[]|ActiveRecord[]
     */
    public static function getHelp($page = '1')
    {
        return self::find()->select(['id', 'title', 'content', 'updated_at'])->where('type = 3 and status = 1')->offset(($page - 1) * 10)->limit(10)->orderBy('updated_at desc')->all();
    }


}
