<?php

namespace common\models;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "chain_bankcard".
 *
 * @property string $id
 * @property string $uid
 * @property string $bank
 * @property string $card_name
 * @property string $card_num
 * @property integer $card_type
 * @property string $province
 * @property string $city
 * @property string $county
 * @property string $reserved_mobile
 * @property string $status
 * @property string $created_at
 * @property string $updated_at
 */
class Bankcard extends ActiveRecord
{
    const STATUS_ACTIVE = 1;
    const STATUS_DELETED = 0;

    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%bankcard}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['uid', 'card_name', 'card_num'], 'required'],
            [['uid', 'card_num', 'card_type', 'created_at', 'updated_at', 'status'], 'integer'],
            [['bank', 'card_name', 'province', 'city', 'county'], 'string', 'max' => 50],
            [['reserved_mobile'], 'string', 'max' => 11],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => 'ID',
            'uid' => '用户ID',
            'bank' => '银行',
            'card_name' => '持卡人姓名',
            'card_num' => '银行卡号',
            'card_type' => '银行卡类型',
            'province' => '开户省行',
            'city' => '开户市行',
            'county' => '开户支行',
            'reserved_mobile' => '联系方式',
            'created_at' => '创建时间',
            'updated_at' => '更新时间',
        ];
    }

    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at',
            ],
        ];
    }

    /**
     * Finds bankcard by uid
     *
     * @param $uid
     * @return null|static
     */
    public function findByUid($uid)
    {
        return static::findOne(['uid' => $uid, 'status' => self::STATUS_ACTIVE]);
        //return static::find()->where(['uid'=>$uid,'status'=>]);
    }

    /**
     * @param int $type
     * @return int|string
     */
    public static function cardType($type = 1)
    {
        switch ($type) {
            case 1:
                $status = '储蓄卡';
                break;
            case 2:
                $status = '信用卡';
                break;
            default :
                $status = '未知类型';
        }
        return $status;
    }

    /**
     * 判断银行卡类型
     * @param $card
     * @param $bankList
     * @return bool
     */
    public static function bankInfo($card, $bankList)
    {
        $card_8 = substr($card, 0, 8);
        if (isset($bankList[$card_8])) {
            return $bankList[$card_8];
        }
        $card_6 = substr($card, 0, 6);
        if (isset($bankList[$card_6])) {
            return $bankList[$card_6];
        }
        $card_5 = substr($card, 0, 5);
        if (isset($bankList[$card_5])) {
            return $bankList[$card_5];
        }
        $card_4 = substr($card, 0, 4);
        if (isset($bankList[$card_4])) {
            return $bankList[$card_4];
        }
        return false;
    }

    /**
     * 查找用户银行卡列表
     * @param $uid
     * @return array|ActiveRecord[]
     */
    public static function findByid($uid)
    {
        $list = self::find()->where(['uid' => $uid])->orderBy("id desc")->limit(1)->asArray()->all();
        foreach ($list as $k => &$item) {
            $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            $item['updated_at'] = date("Y-m-d H:i:s", $item['updated_at']);
        }
        return $list;
    }

}
