<?php

namespace common\models;

use common\widgets\daterangepicker\DateRangePicker;
use yii\base\Model;
use yii\data\ActiveDataProvider;


/**
 * UserRealSearch represents the model behind the search form about `common\models\UserReal`.
 */
class IntegralReleaseSearch extends IntegralRelease
{
    public $total;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['id', 'uid', 'price',], 'integer'],
            [['type', 'status'], 'string'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function scenarios()
    {
        // bypass scenarios() implementation in the parent class
        return Model::scenarios();
    }

    /**
     * Creates data provider instance with search query applied
     *
     * @param array $params
     *
     * @return ActiveDataProvider
     */
    public function search($params)
    {
        $query = IntegralRelease::find();

        //时间筛选
        $date = \Yii::$app->request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $query->andFilterWhere(['between', 'created_at', strtotime($tmp['0']), strtotime($tmp['1'])]);
        }

        // add conditions that should always apply here

        $dataProvider = new ActiveDataProvider([
            'query' => $query,
        ]);

        $this->load($params);

        if (!$this->validate()) {
            // uncomment the following line if you do not want to return any records when validation fails
            // $query->where('0=1');
            return $dataProvider;
        }

        // grid filtering conditions
        $query->andFilterWhere([
            'uid' => $this->uid,
            'type' => IntegralRelease::Type($this->type),
            'price' => $this->price,
        ]);

        $query->andFilterWhere(['like', 'type', $this->type]);
        $query->orderBy("id desc");
        $this->total = $query->sum('price');
        return $dataProvider;
    }

    /**
     * 关联用户信息
     * @return \yii\db\ActiveQuery
     */
    public function getUser()
    {
        return $this->hasOne(User::className(), ['uid' => 'uid']);
    }
}
