<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/9/28 20:58
 */

namespace common\models;

use Yii;
use yii\base\Exception;
use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;
use yii\helpers\ArrayHelper;
use yii\web\IdentityInterface;

/**
 * @property int $uid [int(11) unsigned]  用户uid
 * @property string $mobile [varchar(11)]  手机号
 * @property string $password_hash [varchar(255)]  密码
 * @property string $auth_key [varchar(50)]  cookie验证
 * @property bool $error_password [tinyint(1) unsigned]  密码错误次数
 * @property int $groupid [int(11) unsigned]  组ID
 * @property string $pay_password [varchar(255)]  支付密码
 * @property int $credit [decimal(11,2) unsigned]  余额
 * @property int $integral [decimal(11,2) unsigned]  已释放积分
 * @property int $integral1 [decimal(11,2) unsigned]  待释放积分
 * @property int $outs [decimal(11,2) unsigned]  待释放积分
 * @property string $realname [varchar(50)]  真实姓名
 * @property string $nickname [varchar(50)]  昵称
 * @property string $avatar [varchar(255)]  头像
 * @property integer $gender [tinyint(1) unsigned]  性别 0:女,1:男
 * @property string $qq [varchar(20)]  qq号
 * @property string $email [varchar(50)]  邮箱
 * @property int $created_at [int(11) unsigned]  创建时间
 * @property int $report_center 报单中心
 * @property int $report 报单中心
 * @property int $updated_at [int(11) unsigned]  更新时间
 * @property bool $status [tinyint(1)]  0正常,9冻结,8软删除
 * @property bool $level [tinyint(1) unsigned]  用户等级
 * @property string $access_token [varchar(255)]  API认证
 * @property string $superior [varchar(255)]  下级列表
 * @property string $username [varchar(255)]  下级列表
 * @property string $referrer [varchar(11)]  推荐人
 * @property int $lock_version [int(11) unsigned]
 * @property bool $real_status [tinyint(1)] 实名认证状态
 * @property int $idcard [bigint(18)] 身份证号
 * @property int $is_withdrawn [bigint(18)] 身份证号
 * @property string $address [varchar(255)] 详细地址
 * @property string $partner_address [varchar(255)] 详细地址
 * @property string $domicile_address [varchar(255)] 户籍地址
 * @property string $province [varchar(255)] 户籍地址
 * @property string $city [varchar(255)] 户籍地址
 * @property string $district [varchar(255)] 户籍地址
 * @property int $cardNum [int(11)] 会员卡号
 * @property int $partner [int(11)] 会员卡号
 * @property bool $lv2 [smallint(10)] 志愿者级别
 * @property bool $consumption [smallint(3)    ] 消费级别
 * @property string $remark [varchar(255)] 实名认证驳回
 * @property string $credit1 [decimal(11,2) unsigned] 志愿者余额
 * @property string $credit2 [decimal(11,2) unsigned] 志愿者余额
 * @property string $credit3 [decimal(11,2) unsigned] 志愿者余额
 */
class User extends ActiveRecord implements IdentityInterface
{
    const STATUS_ACTIVE = 0;
    const STATUS_DELETED = 9;
    // 接口认证过期时间
    const ACCESS_TOKEN_EXPIRE = 7200;
    const INTEGRAL_ADD = 1;
    const INTEGRAL_SUB = 2;


    private $password_reset_token;

    public function scenarios()
    {
        $scenarios = parent::scenarios();
        $scenarios['first'] = ['mobile'];
        return $scenarios;
    }

    const  LV = [
        0 => '其他',
        1 => '董事长',
        2 => '销售经理',
        3 => '财务经理',
        4 => '市场经理',
        5 => '拓展经理',
        6 => '人事经理',
        7 => '运营经理',
        8 => '客户经理',
        9 => '行政经理',
    ];
    
    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['mobile',], 'match', 'pattern' => '/^1[0-9]{10}$/', 'message' => '手机号必须为1开头的11位纯数字'],
//            [['mobile'], 'unique', 'message' => '手机号已经存在', 'on' => 'first'],
            [['mobile', 'auth_key', 'password_hash'], 'required'],
            [['uid', 'gender', 'birthyear', 'is_withdrawn', 'birthmonth', 'birthday', 'status', 'real_status', 'gesture', 'outs', 'report_center', 'report', 'updated_at', 'created_at', 'lock_version', 'partner'], 'integer'],
            [['credit', 'credit1', 'credit2', 'credit3', 'report_price'], 'number'],
            [['mobile', 'referrer'], 'string', 'max' => 11],
            [['auth_key', 'email', 'wechat_openid',], 'string', 'max' => 50],
            [['password_hash', 'password_reset_token', 'pay_password', 'avatar', 'address', "partner_address", 'district', 'domicile_address', 'identity0', 'access_token', 'bank_card', 'bank_address'], 'string', 'max' => 255],
            [['realname', 'username'], 'string', 'max' => 15],
            [['nickname', 'province', 'city', 'county',], 'string', 'max' => 20],
            [['idcard'], 'string', 'max' => 18],
            [['identity1', 'identity2'], 'string', 'max' => 100],
            [['superior'], 'string', 'max' => 2000],
            [['credit',], 'number', 'min' => 0, 'tooSmall' => '{attribute}数量不足！'],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'uid' => '用户UID',
            'mobile' => '手机号',
            'superior' => "上级关系",
            'password_hash' => '密码',
            'auth_key' => 'cookie验证',
            'password_reset_token' => 'Password Reset Token',
            'error_password' => '密码错误次数',
            'credit' => '销售积分',
            'credit1' => '出局积分',
            'credit2' => '冻结积分',
            'credit3' => '总金额',
            'realname' => '受益人',
            'identity0' => '手持身份证',
            'identity1' => '身份证正面',
            'identity2' => '身份证反面',
            'nickname' => '昵称',
            'avatar' => '头像',
            'gender' => '性别',
            'outs' => '出局次数',
            'qq' => 'qq号',
            'email' => '邮箱',
            'created_at' => '创建时间',
            'updated_at' => '更新时间',
            'status' => '状态',
            'real_status' => '实名认证状态',
            'idcard' => '身份证号',
            'access_token' => 'API认证',
            'referrer' => '推荐人Uid',
            'bank_card' => '银行卡号',
            'consumption' => '消费级别',
            'bank_address' => '开户行地址',
            'report_price' => '代理金额',
            'partner' => '是否为代理',
            'volunteer' => '志愿者级别',
            "employs"=>"股东数量(点击可查看详情)",
            'name' => '姓名',
            'price' => '价格',
            'is_auto' => '是否自动排序',
            'team_list' => '组号',
            'posi' => '组位置',
            "accountname"=>"登录账户",
          "username"=>"销售名",
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at',
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public static function findIdentity($uid)
    {
        return static::findOne(['uid' => $uid, 'status' => self::STATUS_ACTIVE]);
    }

    /**
     * 生成access_token
     * @throws Exception
     */
    public function generateAccessToken()
    {
        $this->access_token = Yii::$app->security->generateRandomString();
        $this->save();
    }

    /**
     * @inheritdoc
     */
    public static function findIdentityByAccessToken($token, $type = null)
    {
        $token = json_decode(base64_decode($token), true);
        if (!empty($token['uid']) && !empty($token['timestamp']) && ($token['timestamp'] + self::ACCESS_TOKEN_EXPIRE) >= time()) {
            $user = static::findIdentity($token['uid']);
            if (!empty($user) && $token['sign'] === md5($token['uid'] . $token['timestamp'] . $user->access_token)) {
                return $user;
            }
        }
        return null;
    }

    /**
     * @inheritdoc
     */
    public static function findByCardNum($cardNum)
    {
        return static::findOne(['cardNum' => $cardNum, 'status' => self::STATUS_ACTIVE]);
    }

    /**
     * @inheritdoc
     */
    public function getId()
    {
        return $this->getPrimaryKey();
    }

    /**
     * @inheritdoc
     */
    public function getAuthKey()
    {
        return $this->auth_key;
    }

    /**
     * @inheritdoc
     */
    public function validateAuthKey($authKey)
    {
        return $this->getAuthKey() === $authKey;
    }

    /**
     * vilidatemobile
     * @param $mobile
     * @return true/false
     */
    public function validateMobile($mobile)
    {
        return self::find()->where(['mobile' => $mobile])->andWhere(['mobile' => $mobile])->exists();

    }

    /**
     * Validates password
     *
     * @param string $password password to validate
     * @return bool if password provided is valid for current user
     */
    public function validatePassword($password)
    {
        return Yii::$app->security->validatePassword($password, $this->password_hash);
    }

    /**
     * Generates password hash from password and sets it to the model
     * @param $password
     * @throws Exception
     */
    public function setPassword($password)
    {
        $this->password_hash = Yii::$app->security->generatePasswordHash($password, 6);
    }

    /**
     * Generates "remember me" authentication key
     * @throws Exception
     */
    public function generateAuthKey()
    {
        $this->auth_key = Yii::$app->security->generateRandomString();
    }

    /**
     * Generates new password reset token
     * @throws Exception
     */
    public function generatePasswordResetToken()
    {
        $this->password_reset_token = Yii::$app->security->generateRandomString() . '_' . time();
    }

    /**
     * Removes password reset token
     */
    public function removePasswordResetToken()
    {
        $this->password_reset_token = null;
    }


    /**
     * Finds user by mobile
     *
     * @param $mobile
     * @return null|static
     */
    public static function findByMobile($mobile)
    {
        //if(preg_match("/^1[345678]\d{9}$/", $mobile)){
           // $sear=['mobile' => $mobile, 'status' => self::STATUS_ACTIVE];
        //}else{
            $sear=['accountname' => $mobile, 'status' => self::STATUS_ACTIVE];
       // }

        return static::findOne($sear);
    }

    /**
     * Finds user by uid
     *
     * @param $uid
     * @return self
     * @throws \yii\db\Exception
     */
    public static function findByUid($uid)
    {
        $user = static::findOne(['uid' => $uid, 'status' => self::STATUS_ACTIVE]);
        if (empty($user)) {
            return array();
//            throw new \yii\db\Exception('用户不存在或被停用');
        }
        return $user;
    }
    /**
     * Finds user by accountname
     *
     * @param accountname
     * @return self
     * @throws \yii\db\Exception
     */
    public static function findByAccount($account)
    {
        $user = static::findOne(['accountname' => $account, 'status' => self::STATUS_ACTIVE]);
        if (empty($user)) {
            return array();
//            throw new \yii\db\Exception('用户不存在或被停用');
        }
        return $user;
    }

    /**
     * @inheritdoc
     */
    public function optimisticLock()
    {
        return 'lock_version';
    }


    /**
     * @param int $status
     * @return int|string
     */
    public static function realStatus($status = 0)
    {
        switch ($status) {
            case 0:
                $status = '<span class="badge bg-red">未认证</span>';
                break;
            case 1:
                $status = '<span class="badge bg-yellow">认证中</span>';
                break;
            case 2:
                $status = '<span class="badge bg-green">已认证</span>';
                break;
        }
        return $status;
    }

    /**
     * @param $data
     * @return bool
     */
    public function addUserLoginLog($data)
    {
        foreach ($data as $key => $value) {
            $this->$key = $value;
        }
        $this->created_at = time();
        return $this->save();
    }

    /**
     * 查找直推个数
     * @param $uid
     * @return int|string
     */
    public static function findChildrenNum($uid)
    {
        $num = User::find()->where(" superior REGEXP '^{$uid}_' ")->count(1);
        return $num;
    }

    public static function findNameByid($uid)
    {
        $name = User::findOne(['uid' => $uid]);
        return $name;
    }

    /**
     * @param int $parentId
     * @return array
     */
    public static function getRegion($parentId = 0)
    {
        $result = Region::find()->where(['parent_id' => $parentId])->asArray()->all();
        return ArrayHelper::map($result, 'id', 'name');
    }

    public static function findMobileOrUid($uid)
    {
        $user = User::find()->where(['mobile' => $uid])->asArray()->one();
        return $user;
    }

    /**
     * 我的直推信息
     * @param $uid
     * @param $page
     * @return mixed
     */
    public static function ChildrenList($uid, $page)
    {
        $count = User::find()->where(" superior REGEXP '^{$uid}_' ")->count(1);
        $list = User::find()->where(" superior REGEXP '^{$uid}_' ")->offset(($page - 1) * 10)->limit(10)->asArray()->all();
        $data = [];
        foreach ($list as $K => $item) {
//            $data[$K]['uid'] = 'HC' . substr($item['mobile'], -6);
            $data[$K]['uid'] = $item['uid'];
            $data[$K]['realname'] = $item['realname'];
            $data[$K]['mobile'] = $item['mobile'];
            $data[$K]['outs'] = $item['outs'];
            $data[$K]['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
        }
        $ls['page'] = ceil($count / 10);
        $ls['list'] = $data;
        return $ls;
    }

    /**
     * 查找下级
     * @param $data
     * @return array
     */
    public static function disTree($data)
    {
        $tree = array();
        foreach ($data as $item) {
            $pid = 0;
            if ($item['superior'] !== "0") {
                preg_match('/^\d*_/', $item['superior'], $matches);
                if (!empty($matches)) {
                    $pid = trim($matches[0], "_");
                }
            }
            if (!empty($data[$pid])) {
                $data[$pid]['children'][] = &$data[$item['id']];
            } else {
                $tree[] = &$data[$item['id']];
            }
        }
        return $tree;
    }

    /**
     * 查找我的团队
     * @param $uid
     * @return array
     */
    public static function RelationList($uid)
    {
        $userData = $data = [];
        $user = User::find()->select(['uid', 'nickname', 'mobile', 'realname', 'superior', 'outs'])->where(['uid' => $uid])->asArray()->one();
        $temp = User::find()->select(['uid', 'nickname', 'mobile', 'realname', 'superior', 'outs'])->where(" superior REGEXP '^{$uid}_|_{$uid}_' ")->asArray()->all();
        array_push($temp, $user);
        foreach ($temp as $key => $val) {
            $val["text"] = "姓名：<span id='{$val['nickname']}'>" . $val['realname'] . "</span><e style='color:#aaa;font-size:15px' id='{$val['uid']}'>&lt;" . 'ID:' . $val['uid'] . "&gt;</e>" . '出局次数:<e style=\'color:#aaa;font-size:15px\'>&lt;' . $val['outs'] . '次&gt;</e>';
            $val["id"] = $val['uid'];
            $userData[$val['uid']] = $val;
        }
        $data = self::disTree($userData);
        return $data;
    }
    /*查询
     * $username:销售名
     * */
    public static function findByUsername($username)
    {

        $user = static::find()->where("username=:username", [':username' => $username])->one();
        if (empty($user)) {
            return array();
        }
        return $user;
    }

    /*查询
     *$accountname:登录账号
     * */
    public static function findByAccountname($accountname)
    {
        $user = static::find()->where("accountname=:accountname ", [':accountname' => $accountname])->one();
        if (empty($user)) {
            return array();
        }
        return $user;
    }
  

}
