<?php

namespace common\models;

use yii\behaviors\TimestampBehavior;
use yii\db\ActiveRecord;

/**
 * This is the model class for table "{{%withdraw}}".
 *
 * @property integer $id
 * @property integer $uid
 * @property string $bank_name
 * @property string $bank_card
 * @property string $withdraw_money
 * @property string $withdraw_percent
 * @property string $price
 * @property string $remark
 * @property integer $status
 * @property integer $pay_type
 * @property integer $created_at
 * @property integer $updated_at
 * @property string $order_id
 * @property integer $type
 */
class Withdraw extends ActiveRecord
{
    /**
     * @inheritdoc
     */
    public static function tableName()
    {
        return '{{%withdraw}}';
    }

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['uid', 'withdraw_money', 'withdraw_percent', 'price', 'order_id'], 'required'],
            [['uid', 'status', 'created_at', 'updated_at', "pay_type"], 'integer'],
            [['withdraw_money', 'withdraw_percent', 'price'], 'number'],
            [['bank_name', 'bank_card', 'address'], 'string', 'max' => 255],
            [['remark'], 'string', 'max' => 5000],
        ];
    }

    /**
     * @inheritdoc
     */
    public function attributeLabels()
    {
        return [
            'id' => '序号',
            'uid' => '用户ID',
            "username" => "用户名",
            'order_id' => '订单ID',
            'bank_name' => '银行名',
            'bank_card' => '银行卡号',
            'withdraw_money' => '到账金额',
            'withdraw_percent' => '提取手续费',
            'price' => '所需积分',
            'status' => '审核状态',
            'pay_type' => '提现到',
            'remark' => '驳回原因',
            'created_at' => '提取时间',
            'updated_at' => '审核时间',
        ];
    }

    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            [
                'class' => TimestampBehavior::className(),
                'createdAtAttribute' => 'created_at',
                'updatedAtAttribute' => 'updated_at',
            ],
        ];
    }

    /**
     * 根据类型查找数据
     * @param $type
     * @param $uid
     * @param $page
     * @param $limit
     * @return array|\yii\db\ActiveRecord[]
     */
    public function findByType($type, $uid, $page, $limit = '5')
    {
        if ($type == 1) {
            return self::find()->where('type in (1,6,7)')->andWhere(['uid' => $uid])->offset($page * $limit)->limit($limit)->orderBy('created_at desc')->asArray()->all();
        } elseif ($type == 2) {
            return self::find()->where(['type' => $type, 'uid' => $uid])->offset($page * $limit)->limit($limit)->orderBy('created_at desc')->asArray()->all();
        } elseif ($type == 3) {
            return self::find()->where('type in (4,5)')->andWhere(['uid' => $uid])->offset($page * $limit)->limit($limit)->orderBy('created_at desc')->asArray()->all();
        } elseif ($type == 4) {
            return self::find()->where('type in (3,8)')->andWhere(['uid' => $uid])->offset($page * $limit)->limit($limit)->orderBy('created_at desc')->asArray()->all();
        }

    }

    /**
     * 获取兑换状态
     * @param $data
     * @return string
     */
    public function payPayType($data)
    {
        switch ($data) {
            case 1 :
                return '银行卡';
                break;
            case 2 :
                return '零钱';
                break;
            case 3:
                return '志愿者账户';
                break;
            default :
                return '未知类型';
        }
    }

    /**
     * 获取兑换状态
     * @param $data
     * @return string
     */
    public static function payStatus($data)
    {
        switch ($data) {
            case 0 :
                return '未审核';
                break;
            case 1 :
                return '审核中';
                break;
            case 2:
                return '已完成';
                break;
            case 3:
                return '已驳回';
                break;
            default :
                return '未知状态';

        }
    }

    /**
     * 查看是否体现
     * @param $uid
     * @param $type
     * @return int|string
     */
    public function withdraNum($uid, $type)
    {
        $end_time = date('Y-m-d', time());
        $start_time = date("Y-m-d", strtotime("-1 week"));
        if ($type == 1) {
            return self::find()->where(['uid' => $uid])->andWhere(['pay_type' => $type])->andWhere(["status" => 2])->andWhere(['between', "FROM_UNIXTIME(created_at, '%Y-%m-%d')", $start_time, $end_time])->count();
        }
        return self::find()->where(['uid' => $uid])->andWhere(['pay_type' => $type])->andWhere(["FROM_UNIXTIME(created_at, '%Y-%m-%d')" => $end_time])->count();
    }

    /**
     * 合计
     * @param $type
     * @param $uid
     * @return mixed
     */
    public function countGold($type, $uid)
    {
        if ($type == 1) {
            return self::find()->where('type in (1,6,7)')->andWhere(['uid' => $uid])->andWhere(['status' => 2])->sum('withdraw_money');
        } elseif ($type == 2) {
            return self::find()->where(['type' => $type])->andWhere(['uid' => $uid])->andWhere(['status' => 2])->sum('withdraw_money');
        } elseif ($type == 3) {
            return self::find()->where('type in (4,5)')->andWhere(['uid' => $uid])->andWhere(['status' => 2])->sum('withdraw_money');
        } else {
            return self::find()->where(['uid' => $uid])->andWhere("type in (3,8)")->andWhere(['status' => 2])->sum('withdraw_money');
        }
    }

    /**
     * 查找兑换记录
     * @param $uid
     * @param $page
     * @return array|ActiveRecord[]
     */
    public static function WithdrawList($uid, $page)
    {
        $pages = self::find()->where(['uid' => $uid])->count(1);
        $list = self::find()->where(['uid' => $uid])->orderBy("id desc")->offset(($page - 1) * 10)->limit(10)->asArray()->all();
        foreach ($list as $k => &$item) {
            $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            $item['updated_at'] = date("Y-m-d H:i:s", $item['updated_at']);
            $item['status'] = self::payStatus($item['status']);
            if ($item['pay_type'] == 2) {
                $item['price'] = $item['price'] . " 个";
                $item['withdraw_percent'] = $item['withdraw_percent'] . " 个";
            } else {
                $item['price'] = $item['price'] . " 元";
                $item['withdraw_percent'] = $item['withdraw_percent'] . " 元";
            }
            $item['withdraw_money'] = $item['withdraw_money'] . " 元";
        }
        $ls['page'] = ceil($pages / 10);
        $ls['list'] = $list;
        return $ls;
    }


}
