<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/12/7 11:55
 */

namespace console\controllers;

use Swoole\Server;
use yii\console\Controller;

class SwooleController extends Controller
{
    private $serv;

    public function actionIndex()
    {
        $this->serv = new Server("127.0.0.1", 9502);
        $this->serv->set([
            'worker_num' => 8,
            'daemonize' => false,
            'task_worker_num' => 200,
            'log_file' => 'swoole.log'
        ]);

        $this->serv->on('Start', array($this, 'onStart'));
        $this->serv->on('Connect', array($this, 'onConnect'));
        $this->serv->on('Receive', array($this, 'onReceive'));
        $this->serv->on('Task', array($this, 'onTask'));
        $this->serv->on('Finish', array($this, 'onFinish'));

        $this->serv->start();
    }

    /**
     * Server启动在主进程的主线程回调此函数，函数原型
     */
    public function onStart()
    {
        $this->say('Starting');
    }

    /**
     * 有新的连接进入时，在worker进程中回调
     */
    public function onConnect()
    {
        $this->say('Connected');
    }

    /**
     * 接收到数据时回调此函数，发生在worker进程中
     * @param Server $server
     * @param int $fd
     * @param int $reactor_id
     * @param string $data
     */
    public function onReceive(Server $server, $fd, $reactor_id, $data)
    {
        $this->say('Receive', $data);
        $data = json_decode($data, true);
        if (empty($data) || empty($data['act'])) {
            $this->say('Invalid data');
            return;
        }
        $server->task($data);
    }

    /**
     * 接受任务
     * @param Server $serv
     * @param int $task_id
     * @param int $src_worker_id
     * @param array $data
     */
    public function onTask(Server $serv, $task_id, $src_worker_id, $data)
    {
        $this->say('Tasking');
        \Yii::$app->runAction('pos/' . $data['act'], [$data['data']]);
    }

    /**
     * 当worker进程投递的任务在task_worker中完成时
     * @param Server $serv
     * @param int $task_id
     * @param string $data
     */
    public function onFinish(Server $serv, $task_id, $data)
    {
        $this->say('Finished');
    }

    /**
     * 输出到控制台
     * @param string $msg
     * @param null $data
     */
    private function say($msg, $data = null)
    {
        $str = $msg;
        if (!empty($data)) {
            $str .= ': ';
        }
        if (is_array($data)) {
            $str .= json_encode($msg);
        } else {
            $str .= $data;
        }
        echo date('Y-m-d H:i:s') . ' ' . $str . PHP_EOL;
    }
}
