<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2018/1/22 HNDH Software Technology Co., Ltd.
 * @link http://www.dhsoft.cn
 */

namespace frontend\controllers;


use backend\models\DistributionConfig;
use common\helpers\Utils;
use common\models\Announcement;
use common\models\ArticleList;
use common\models\Bankcard;
use common\models\Custom;
use common\models\Proxy;
use common\models\Region;
use common\models\ShopCart;
use common\models\ShopGoods;
use common\models\Team;
use common\models\User;
use common\models\UserOrder;
use common\models\Withdraw;
use frontend\models\ResetPasswordForm;
use common\models\ReportForm;
use Yii;
use yii\base\Exception;
use yii\db\Expression;

class UserController extends ControllerBase
{
    /**
     * 个人资料
     * @return array
     */
    public function actionUserInfo()
    {
        $uid = \Yii::$app->user->id;
        $userInfo = User::find()->select(['uid', 'superior', 'outs', 'report_center', 'credit', 'credit1', 'credit2', 'credit3', 'report', 'partner', 'partner_address', 'realname', 'avatar', 'created_at', "mobile"])->where(['uid' => $uid])->asArray()->one();
        if (empty($userInfo)) {
            return $this->responseJson(1, '', '参数错误！');
        } else {
            if (!empty($userInfo['avatar'])) {
                $userInfo['avatar'] = Utils::toMedia($userInfo['avatar']);
            }
            $list = Bankcard::findByid($uid);
            $userInfo['zhi'] = User::findChildrenNum($uid);
            $userInfo['created_at'] = date("Y-m-d H:i:s", $userInfo['created_at']);
            $userInfo['bankcard'] = $list;
//            $userInfo['uid'] = 'HC' . substr($userInfo['mobile'], -6);
//            $relation['superior'] = rtrim($userInfo['superior'], '_0');
            $username = User::find()->select([ 'realname', "accountname"])->where(['uid' => $userInfo['superior']])->one();
            $relation['superior']=$username['accountname']?$username['accountname']:$username['realname'];
            $rela = explode('_', $relation['superior']);
            $userInfo['superior'] = empty($rela[0]) ? 0 : $rela[0];
            return $this->responseJson(0, $userInfo, "返回数据成功");
        }
    }

    /**
     * 修改姓名
     * @return array
     */
    public function actionEditName()
    {
        $uid = \Yii::$app->user->id;
        $name = \Yii::$app->request->post('name');
        $user = User::findOne(['uid' => $uid]);
        $user->realname = $name;
        if ($user->save()) {
            $data = [
                'report' => $user['report'],
                'partner' => $user['partner'],
                'name' => $user['realname'],
            ];
            return $this->responseJson(0, $data, '修改成功！');
        } else {
            return $this->responseJson(1, '', '修改失败！' . current($user->getFirstErrors()));
        }
    }


    /**
     * 提交订单
     * @return array
     * @throws \yii\db\Exception
     */
    public function actionOrder()
    {
        $uid = \Yii::$app->user->id;
        $data = \Yii::$app->request->post();
        $data['thumb'] = Utils::base64pic($data['thumb']);
        $model = new UserOrder();
//        if ($model->load($data, '')) {
        if ($this->arrayLoad($model, $data)) {
            if ($model->save()) {
                $user = User::findOne(['uid' => $uid]);
                $user->updateCounters(['credit2' => -$data['price']]);
                return $this->responseJson(0, '', '提交成功');
            } else {
                return $this->responseJson(1, '', '提交失败！请重新提交');
            }
        } else {
            return $this->responseJson(1, '', '提交失败！请重新提交');
        }
    }

    /**
     * 提现验证
     * @return array
     */
    public function actionPrompt()
    {
        $request = \Yii::$app->request;
        //提取金额
        $price = $request->post('price');
        $uid = \Yii::$app->user->id;
        $type = \Yii::$app->request->post('type');
        try {
            $user = User::findOne(['uid' => $uid]);
            if ($type == 2) {
                $status = $user->is_withdrawn;
                if ($status == 0) {
                    throw new Exception('您需先购买车辆,才能提现哦！');
                }
                $money = $user->credit2;
            } else {
                $money = $user->credit;
            }
            $list = Bankcard::find()->where(['uid' => $uid, 'status' => 0])->asArray()->all();
            if (empty($list)) {
                return $this->responseJson(302, '', "您还没有绑定银行卡,快去绑定吧！");
            }
            if (empty($price)) {
                throw new Exception('请填写参数');
            }
            if ($money < $price) {
                throw new Exception('请检查你的余额！');
            }
            return $this->responseJson(0, '', '通过验证！');
        } catch (Exception $e) {
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 验证积分提现
     * @return array
     */
    public function actionIntegral()
    {
        $uid = \Yii::$app->user->id;
        $user = User::findOne(['uid' => $uid]);
        $status = $user->is_withdrawn;
        $type = \Yii::$app->request->post('type');
        if ($status == 0 && $type == 2) { //积分
            return $this->responseJson(1, '', '您需先购买车辆,才能提现哦！');
        } else {
            if ($type == 2) {
                $money = $user->credit2;
            } else {
                $list = Bankcard::findOne(['uid' => $uid]);
                if (empty($list)) {
                    return $this->responseJson(1, '', '请您先添加银行卡！');
                }
                $money = $user->credit;
            }
            return $this->responseJson(0, $money, '验证通过！');
        }
    }


    /**
     * 提现
     * @return array
     * @throws \yii\db\Exception
     */
    public function actionIntegralConvert()
    {
        $request = \Yii::$app->request;
        //积分
        $price = $request->post('price');
        $type = $request->post('type');
        $uid = \Yii::$app->user->id;
        $transaction = \Yii::$app->db->beginTransaction();
        try {
            $model = new Withdraw();
            $user = User::findByUid($uid);
            if ($type == 2) {
                if (bcsub($user->credit2, $price, 2) < 0) {
                    throw new Exception('请检查你的积分！');
                }
                $result = $user->updateCounters(['credit2' => -$price]);
                $results = $user->updateCounters(['credit7' => -$price]);
                if (empty($result) && empty($results)) {
                    throw new Exception('支付失败');
                }
                $status = 1;
                $integral = $price * (1 - DistributionConfig::getAll('index')['consump']['integral'] * 0.01);  //需要读配置表
            } else {
                if ($user->credit < $price) {
                    throw new Exception('请检查金额！');
                }
                $result = $user->updateCounters(['credit' => -$price]);
                if (empty($result)) {
                    throw new Exception('支付失败');
                }
                $status = 1;
                $integral = $price * (1 - DistributionConfig::getAll('index')['consump']['rate'] * 0.01);  //需要读配置表
            }
            $fee = bcsub($price, $integral, 2);
            $bank_model = Bankcard::findOne(['uid' => $uid]);
            if (empty($bank_model)) {
                return $this->responseJson(1, '', '您还未绑定银行卡,请先去绑定银行卡！');
            }
            $bank_address = $bank_model->province . $bank_model->city . $bank_model->county;
            $bank_card = $bank_model->card_num;
            $bank_name = $bank_model->bank;
            $data = [
                'uid' => $user->uid,
                'order_id' => $this->createOrderNumber($uid),
                'bank_name' => $bank_name,
                'address' => $bank_address,
                'bank_card' => "$bank_card",
                'price' => $price,              //提取金额
                'withdraw_money' => $integral,  //打款金额
                'withdraw_percent' => $fee,     //手续费
                'pay_type' => $type,     //手续费
                'status' => $status,
            ];
            if ($model->load($data, '')) {
                if ($model->save()) {
                    $transaction->commit();
                    return $this->responseJson(0, '', '提交信息成功');
                } else {
                    throw new Exception('提交信息失败' . current($model->getFirstErrors()));
                }
            } else {
                throw new Exception('请求错误');
            }
        } catch (Exception $e) {
            $transaction->rollBack();
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 购买商品及商品列表
     * @return array
     */
    public function actionPayGoods()
    {
        $data = \Yii::$app->request->post();
        $count = ShopGoods::find()->where("status=2")->count(1);
        $list = ShopGoods::find()->where("status=2")->offset(($data['page'] - 1) * 10)->limit(10)->asArray()->all();

        if (empty($list)) {
            return $this->responseJson(1, '', '无商品列表！');
        }
        foreach ($list as $k => $v) {
            $list[$k]['imgs'] = Utils::toMedia($v['imgs']);
        }
        $ls['page'] = ceil($count / 10);
        $ls['list'] = $list;
        return $this->responseJson(0, $ls, '返回数据成功！');
    }

    /**
     * 支付
     * @return array
     * @throws Exception
     */
    public function actionPay()
    {
        $uid = Yii::$app->user->id;
        $data = Yii::$app->request->post();
        if (!empty($data['type']) && $data['type'] == 'save') {
            $user = User::findOne(['uid' => $uid]);
//            if ($user->outs == 0) {
//                return $this->responseJson(1, '', '您还未达到购买资格哦！快去推荐人吧！');
//            }
            if (bcsub($user->credit3, $data['price'], 2) < 0) {
                return $this->responseJson(1, '', '请先检查您的积分');
            }
            $orderid = 'ORDER' . $this->createOrderNumber($uid);
            $orderModel = new UserOrder();
            $transaction = \Yii::$app->db->beginTransaction();
            try {
                if (bcsub($user->credit3, $data['price'], 2) >= 0) {
                    $user->updateAttributes(['credit3' => new Expression("credit2-{$data['price']}")]);
                }
                $shopGoogs = ShopGoods::findOne(['id' => $data['id']]);
                $arr = [
                    'uid' => $uid,
                    'order_id' => $orderid,
                    'gid' => $data['id'],
                    'title' => $shopGoogs['title'],
                    'thumb' => $shopGoogs['imgs'],
                    'num' => $data['num'],
                    'price' => $data['price'],
                    'status' => 1,
                ];
                if ($orderModel->load($arr, '')) {
                    if ($orderModel->save()) {
                        $transaction->commit();
                        return $this->responseJson(0, $orderid, '购买成功!');
                    } else {
                        return $this->responseJson(1, '', '购买失败!' . current($orderModel->getFirstErrors()));
                    }
                }
            } catch (Exception $e) {
                $transaction->rollBack();
                throw new Exception("购买失败！" . $e->getMessage());
            }
        }
    }

    /**
     * 添加银行卡
     * @return array
     */
    public function actionAddBank()
    {
        $data = \Yii::$app->request->post();
        $re = $this->ValidateSmsCode($data['mobile'], $data['smsCode']);
        if ($re !== true) {
            return $this->responseJson(1, '', $re);
        }
        if (empty($data) || !is_array($data) || empty($data['card_name']) || empty($data['card_num'])) {
            return $this->responseJson(1, '', '请填写正确的参数');
        }
        $numlist = Bankcard::findOne(['card_num' => $data['card_num']]);
        if (!empty($numlist)) {
            return $this->responseJson(1, '', '此银行卡已被添加，请检查银行卡号！');
        }

        $uid = \Yii::$app->user->id;
        $list = Bankcard::findOne(['uid' => $uid]);
        if (!empty($list)) {
            $list->uid = $uid;
            $list->status = 0;
            $bank = $data['card_name'];
            $list->bank = $bank;
            $list->card_name = $data['user_name'];
            $list->county = $data['address'];
            $list->card_num = $data['card_num'];
            if ($list->save()) {
                return $this->responseJson(0, ['id' => $list->attributes['id'], 'bank' => $bank], '修改银行卡成功');
            } else {
                return $this->responseJson(1, '', '修改银行卡失败');
            }
        } else {
            $model = new Bankcard();
            if ($model->load($data, '')) {
                $model->uid = $uid;
                $model->status = 0;
                $bank = $data['card_name'];
                $model->bank = $bank;
                $model->card_name = $data['user_name'];
                $model->county = $data['address'];
                if ($model->save()) {
                    return $this->responseJson(0, ['id' => $model->attributes['id'], 'bank' => $bank], '添加银行卡成功');
                } else {
                    return $this->responseJson(1, '', '添加银行卡失败');
                }
            } else {
                return $this->responseJson(1, '', '请求失败' . current($model->getFirstErrors()));
            }
        }
    }

    /**
     * 银行卡列表
     * @return array
     */
    public function actionBankList()
    {
        $uid = \Yii::$app->user->id;
        $list = Bankcard::findByid($uid);
        if (empty($list)) {
            return $this->responseJson(1, '', '您还没有银行卡，快去添加吧！');
        } else {
            return $this->responseJson(0, $list, "返回数据成功！");
        }
    }

    /**
     * 兑换列表
     * @return array
     */
    public function actionIntegralList()
    {
        $page = \Yii::$app->request->post('page');
        $uid = \Yii::$app->user->id;
        $list = Withdraw::WithdrawList($uid, $page);
        if (empty($list['list'])) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 订单记录
     * @return array
     */
    // public function actionOrderList()
    // {
    //     $uid = \Yii::$app->user->id;
    //     $page = \Yii::$app->request->post('page');
    //     $list = UserOrder::find()->select(['id', 'title', 'thumb', 'uid', 'order_id', 'num', 'price', 'created_at', 'status'])->where(['uid' => $uid])->orderBy('id desc')->offset(($page - 1) * 5)->limit(5)->asArray()->all();
    //     if (empty($list)) {
    //         return $this->responseJson(1, '', '查询数据为空！');
    //     } else {
    //         foreach ($list as $k => &$item) {
    //             $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
    //             $item['thumb'] = empty($item['thumb']) ? '' : Utils::toMedia($item['thumb']);
    //             if ($item['status'] == 1) {
    //                 $item['status'] = '待审核';
    //             } elseif ($item['status'] == 2) {
    //                 $item['status'] = '已审核';
    //             } else {
    //                 $item['status'] = '已驳回';
    //             }
    //         }
    //         $ls['page'] = ceil(UserOrder::find()->where(['uid' => $uid])->count(1) / 5);
    //         $ls['list'] = $list;
    //         return $this->responseJson(0, $ls, '返回数据成功！');
    //     }
    // }
    public function actionOrderList()
    {
        $uid = \Yii::$app->user->id;
        $page = \Yii::$app->request->post('page');
        $list = ReportForm::find()->where(['uid' => $uid])->orderBy('id desc')->offset(($page - 1) * 5)->limit(5)->asArray()->all();


        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as $k => &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
                $item['thumb'] = empty($item['thumb']) ? '' : Utils::toMedia($item['thumb']);
                if ($item['status'] == 1) {
                    $item['status'] = '待审核';
                } elseif ($item['status'] == 2) {
                    $item['status'] = '已审核';
                } elseif ($item['status'] == 4) {
                    $item['status'] = '财务已审核';
                }else{
                    $item['status'] = '已驳回';
                }
                if ($item['goods_status'] == 1) {
                    $item['goodsstatus'] = '已发货';
                } elseif ($item['goods_status'] == 2) {
                    $item['goodsstatus'] = '已收货';
                } elseif ($item['goods_status'] == 4) {
                    $item['goodsstatus'] = '已退货';
                }elseif ($item['goods_status'] == 0) {
                    $item['goodsstatus'] = '未发货';
                }else {
                    $item['goodsstatus'] = "未知";
                }
            }
            $ls['page'] = ceil(UserOrder::find()->where(['uid' => $uid])->count(1) / 5);
            $ls['list'] = $list;
            return $this->responseJson(0, $ls, '返回数据成功！');
        }
    }
    /*
        确认呢收货

     */
    public function actionConfirm(){
//        $id=8;
        $id = Yii::$app->request->post("id");

        if(!$id){
            return $this->responseJson(0, "", '操作错误请刷新重试！');

//            echo "<script>alert('操作错误请刷新重试');history.go(-1)</script>";die;
        }
        $list = ReportForm::find()->select("goods_status")->where(['id' => $id])->one();
        if(empty($list)){
            return $this->responseJson(0, "", '订单不存在或者被删除请联系客服！');
//            echo "<script>alert('');history.go(-1)</script>";die;
        }else{
           if($list['goods_status']==2){
               return $this->responseJson(0, "", '已经确认收货请勿重复操作！');
//               echo "<script>alert('');history.go(-1)</script>";die;
            }
            if($list['goods_status']==0){
               return $this->responseJson(0, "", '商家未发货！');
//               echo "<script>alert('');history.go(-1)</script>";die;
            }


        }
         $resu=ReportForm::updateAll(["goods_status"=>2,"updated_at"=>time(),"operateid"=>-1],['id' =>$id]); //修改报单
        
         if($resu){
             return $this->responseJson(1, "", '收货成功欢迎下次再来！');

//             echo "<script>alert('');history.go(-1)</script>";die;

         }else{
             return $this->responseJson(0, "", '收货失败请刷新重试！');

//             echo "<script>alert('');history.go(-1)</script>";die;

         }
    }


    /**
     * 公告
     * @return array
     */
    public function actionAnnouncementAgree()
    {
        $list = Announcement::find()->where(['type' => 1])->orderBy('created_at desc')->limit(10)->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
                $item['content'] = Utils::get_img_thumb_url($item['content']);
            }
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 退出用户
     * @return \yii\web\Response
     */
    public function actionBackLogin()
    {
        Yii::$app->user->logout();
    }

    /**
     * 申请代理、报单中心
     * @return array
     */
    public function actionProxy()
    {
        $data = Yii::$app->request->post();
        $user = User::findByMobile($data['mobile']);
        if (empty($user)) {
            return $this->responseJson(1, '', '该用户未注册,请先注册！');
        } else {
            if ($data['type'] == 1) {
                if ($user->partner == 1) {
                    return $this->responseJson(1, '', '您已经是代理了，请把机会留给别人吧');
                }
            } else {
                if ($user->report == 1) {
                    return $this->responseJson(1, '', '您已经是销售中心，请把机会留给别人吧');
                }
            }
            $data['uid'] = $user['uid'];
            $result = Proxy::add($data);
            if ($result == true) {
                return $this->responseJson(0, '', '申请成功！');
            } else {
                return $this->responseJson(1, '', '申请失败,请重新提交！' . $result);
            }
        }
    }

    /**
     * 地区
     * @return array
     */
    public function actionAddress()
    {
        $parentId = Yii::$app->request->post('id');
        $list = Region::getRegion($parentId);
        return $this->responseJson(0, $list, '返回数据成功');
    }

    /**
     * 代理协议
     * @return array
     */
    public function actionAgencyAgreement()
    {
        $list = Announcement::find()->where(['type' => 10])->limit(1)->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            }
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 联系我们
     * @return array
     */
    public function actionContactUs()
    {
        $list = Announcement::find()->where(['type' => 12])->limit(1)->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            }
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 报单中心协议
     * @return array
     */
    public function actionReportAgreement()
    {
        $list = Announcement::find()->where(['type' => 11])->limit(10)->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            }
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 关于我们
     * @return array
     */
    public function actionAbout()
    {
        $list = Announcement::find()->where(['type' => 3])->limit(10)->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date("Y-m-d H:i:s", $item['created_at']);
            }
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 我的分享
     * @return array
     */
    public function actionMyShare()
    {
        $uid = Yii::$app->user->id;
        $page = Yii::$app->request->post('page');
        $list = User::ChildrenList($uid, $page);
        if (empty($list['list'])) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            return $this->responseJson(0, $list, '返回数据成功！');
        }
    }

    /**
     * 我的团队
     * @return array
     */
    public function actionMyTeam()
    {
        $uid = Yii::$app->user->id;
        $list = User::RelationList($uid);
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空！');
        } else {
            return $this->responseJson(0, $list, '返回成功！');
        }
    }

    /**
     * 银行卡支付密码验证
     * @return array
     */
    public function actionValidatePayPwd()
    {
        $payPwd = intval(\Yii::$app->request->post('payPwd'));
        try {
            $user = \Yii::$app->user->identity;
            $this->validatePayPwd($user['pay_password'], $payPwd);
            return $this->responseJson(0, '', '验证成功');
        } catch (Exception $e) {
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 忘记密码
     * @return array
     */
    public function actionReset()
    {
        $uid = Yii::$app->user->id;
        $model = new ResetPasswordForm();
        $model->scenario = 'password';
        $tmp = Yii::$app->request->post();
        $data = [
            'uid' => $uid,
            'password' => $tmp['newpass'],
            'rePassword' => $tmp['repass'],
        ];
        if ($this->arrayLoad($model, $data) && $model->resetPassword()) {
            return $this->responseJson(0, '', '密码设置成功，请登录！');
        } else {
            return $this->responseJson(1, '', current($model->getFirstErrors()));
        }
    }

    /**
     * 修改支付密码
     * @return array
     */
    public function actionResetPayPwd()
    {
        $model = new ResetPasswordForm();
        $model->scenario = 'pay_pwd';
        $tmp = Yii::$app->request->post();
        $data = [
            'mobile' => $tmp['mobile'],
            'uid' => $tmp['userID'],
            'smsCode' => $tmp['smsCode'],
            'payPwd' => $tmp['password'],
        ];
        if ($this->arrayLoad($model, $data) && $model->resetPayPwd()) {
            return $this->responseJson(0, '', '支付密码更新成功');
        } else {
            return $this->responseJson(1, '', current($model->getFirstErrors()));
        }
    }

    /**
     * 添加购物车
     * @return array
     */
    public function actionAddCart()
    {
        $uid = Yii::$app->user->id;
        $data = Yii::$app->request->post();
        $goodsInfo = ShopGoods::findOne(['id' => $data['id']]);
        $dataInfo = [
            'uid' => $uid,
            'goods_id' => $data['goods_id'],
            'goods_price' => $goodsInfo['price'],
            'goods_name' => $goodsInfo['title'],
            'goods_num' => $data['goods_num'],
            'thumb' => $goodsInfo['imgs'],
            'status' => 1,
            'created_at' => time(),
        ];
        $re = ShopCart::add($dataInfo);
        if ($re == true) {
            return $this->responseJson(0, '', '添加成功！');
        } else {
            return $this->responseJson(1, '', '添加失败！');
        }
    }

    /**
     * 删除购物车
     * @return array
     */
    public function actionDeleteCart()
    {
        $uid = Yii::$app->user->id;
        $data = Yii::$app->request->post();
        $datainfo = [
            'uid' => $uid,
            'id' => $data['id'],
        ];
        $re = ShopCart::deleteCart($datainfo);
        if ($re == true) {
            return $this->responseJson(0, '', '删除成功');
        } else {
            return $this->responseJson(1, '', '删除失败！');
        }
    }

    /**
     * 定制车型
     * @return array
     */
    public function actionCustom()
    {
        $uid = Yii::$app->user->id;
        $data = Yii::$app->request->post();
//        $user = User::findOne(['uid' => $uid]);
//        if ($user->credit2 <= Config::getConfig("LOWEST_POINTS")) {  // Config::getConfig("LOWEST_POINTS");
//            return $this->responseJson(1, '', "您的积分不足{Config::getConfig('LOWEST_POINTS')},请先赚取积分再来购车吧！");
//        }
        $model = new  Custom();
        $datainfo = [
            'uid' => $uid,
            'name' => $data['name'],
            'mobile' => $data['mobile'],
            'model' => $data['type'],
            'color' => $data['color'],
            'remark' => $data['remarks'],
            'created_at' => time(),
            'updated_at' => time(),
        ];
//        if ($model->load($datainfo, '')) {
        if ($this->arrayLoad($model, $datainfo)) {
            if ($model->save()) {
                return $this->responseJson(0, '', '提交成功！');
            } else {
                return $this->responseJson(1, '', '提交失败！' . current($model->getFirstErrors()));
            }
        } else {
            return $this->responseJson(1, '', '提交失败！' . current($model->getFirstErrors()));
        }
    }

    /**
     * 商城幻灯片
     * @return array
     */
    public function actionShopIndex()
    {
        $list = ArticleList::find()->select(['pic'])->where(['cid' => 26])->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空');
        } else {
            foreach ($list as &$item) {
                $item['pic'] = Utils::toMedia($item['pic']);
            }
            return $this->responseJson(0, $list, '返回数据成功');
        }
    }

    /**
     * 疑难帮助
     * @return array
     */
    public function actionDifficultHelp()
    {
        $list = ArticleList::find()->where(['cid' => 0])->asArray()->all();
        if (empty($list)) {
            return $this->responseJson(1, '', '查询数据为空');
        } else {
            foreach ($list as &$item) {
                $item['created_at'] = date($item['created_at']);
            }
            return $this->responseJson(0, $list, '返回数据成功');
        }
    }

    /**
     * 查找团队
     * @return array
     */
    public function actionFindTeam()
    {
        $mobile = Yii::$app->request->post('mobile');
        $user = User::findNameByid($mobile);
        if (empty($user)) {
            return $this->responseJson(1, '', '该用户未注册');
        } else {
            $team = Team::findByMoblie($user['uid']);
            if (empty($team)) {
                return $this->responseJson(1, '', '查找数据为空！');
            } else {
                $list['page'] = ceil(count($team) / 5);
                $list['list'] = $team;
                return $this->responseJson(0, $list, "返回数据成功");
            }
        }
    }
    /*
        查找用户信息
        uid:用户id
    */
     public function actionGetInfo(){
         $mobile = Yii::$app->request->post('mobile');
        $user = User::findNameByid($mobile);
        if (empty($user)) {
            return $this->responseJson(1, '', '信息错误或不存在');
        } else {
            return $this->responseJson(0, $user, "返回数据成功");
        }
     }
}
