<?php
/**
 * @author 河南鼎汉软件科技
 * @copyright Copyright (c) 2017 HNDH Software Technology Co., Ltd.
 * createtime: 2017/8/24 17:46
 */

namespace frontend\models;


use common\models\SmsVerifycode;
use common\models\User;
use yii\base\Model;

class RegisterForm extends Model
{
    public $mobile;
    public $password;
    public $smsCode;
    public $referrer;
    public $verifyCode;
    public $superior;
    public $wechat_openid;
    //public $grade;

    /**
     * @inheritdoc
     */
    public function rules()
    {
        return [
            [['mobile', 'smsCode'], 'trim'],
            [['mobile', 'smsCode', 'password'], 'required'],
            [['mobile'], 'match', 'pattern' => '/^1[0-9]{10}$/', 'message' => '手机号必须为1开头的11位纯数字'],
            ['mobile', 'unique', 'targetClass' => '\common\models\User', 'message' => '注册失败，手机号已被注册！'],
            ['referrer', 'checkReferrer'],
            [['password'], 'match', 'pattern' => '/^(?!\d+$)(?![A-Za-z]+$)[a-zA-Z0-9]{6,16}$/', 'message' => '密码太过简单,请输入6-16数字加字母格式密码'],
            ['smsCode', 'validateSmsCode'],
            [['wechat_openid'], 'safe'],
        ];
    }

    public function checkReferrer($attribute)
    {
        $referrerUser = User::findByMobile($this->referrer);
        if (empty($referrerUser)) {
            $this->addError('referrer', '邀请人不存在！');
        } else {
            $this->superior = $referrerUser->uid . '_' . $referrerUser->superior;
        }
    }

    /**
     * 验证短信验证码
     * @param string $attribute
     */
    public function validateSmsCode($attribute)
    {

        if (!$this->hasErrors()) {
            $smsVerifycode = new SmsVerifycode();
            if (strlen($this->smsCode) != 4) {
                $this->addError($attribute, strlen($this->smsCode));
            }
            $result = $smsVerifycode->check($this->mobile, $this->smsCode);
            if ($result !== true) {
                $this->addError($attribute, $result);
            }
        }
    }

    public function attributeLabels()
    {
        return [
            'mobile' => '手机号',
            'password' => '密码',
            'smsCode' => '短信验证码',
            'referrer' => '邀请人手机号',
            'verifyCode' => '图片验证码',
        ];
    }

    /**
     * @return bool|mixed
     */
    public function register()
    {
        $this->beforeValidate();
        if ($this->validate()) {
            $user = new User();
//            echo $this->accoutname;die;
            $user->mobile = $this->mobile;
            $user->referrer = $this->referrer;
            $user->superior = $this->superior;
            $user->wechat_openid = $this->wechat_openid;
            $user->setPassword($this->password);
            $user->generateAuthKey();
            $user->scenario = 'first';

            return $user->save();
        }
        return false;
    }
}
