<?php

namespace frontend\modules\sp\controllers;

use common\models\OfflinePay;
use common\models\OpenCard;
use common\models\User;
use common\widgets\daterangepicker\DateRangePicker;
use yii\base\Exception;
use yii\filters\AccessControl;

class SiteController extends ControllerBase
{
    /**
     * @inheritdoc
     */
    public function behaviors()
    {
        return [
            'access' => [
                'class' => AccessControl::className(),
                'rules' => [
                    [
                        'allow' => true,
                        'roles' => ['@', '?'],
                    ],
                ],
            ],
        ];
    }

    /**
     * @inheritdoc
     */
    public function actions()
    {
        return [
            'error' => [
                'class' => 'yii\web\ErrorAction',
            ],
        ];
    }

    /**
     * 首页信息
     * @return string
     */
    public function actionIndex()
    {
        $cardNum = \Yii::$app->request->post('cardNum');
        $price = \Yii::$app->request->post('price');
        return $this->render('index', ['cardNum' => $cardNum, 'price' => $price]);
    }


    /**
     * 商家结账验证
     * @return array
     */
    public function actionPay()
    {
        $request = \Yii::$app->request;
        $cardNum = $request->post('cardNum');
        $price = $request->post('money');
        $pay_pwd = $request->post('password');
        try {
            $user = User::findByCardNum($cardNum);
            if ($price < 0 || !is_numeric($price)) {
                throw new Exception('请填写正确的金额');
            }
            if (empty($pay_pwd) || !is_numeric($pay_pwd) || strlen($pay_pwd) != 6) {
                throw new Exception('请填写正确的支付密码');
            }
            if (empty($user)) {
                throw new Exception('用户不存在');
            }
            if ($user->pay_password != md5($pay_pwd)) {
                throw new Exception('支付密码错误');
            }
            if (bccomp($user->credit, $price) <= 0) {
                throw new Exception('用户余额不足');
            }
            return $this->responseJson(0, '', '验证成功');
        } catch (Exception $e) {
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 商家确认结账
     * @return array
     */
    public function actionOfflinePay()
    {
        $request = \Yii::$app->request;
        $cardNum = $request->post('cardNum');
        $price = $request->post('money');
        $pay_pwd = $request->post('password');
        $remark = $request->post('remark');
        $shop_id = \Yii::$app->user->id;
        $user = User::findByCardNum($cardNum);
        $transaction = \Yii::$app->db->beginTransaction();
        try {
            if (empty($user)) {
                throw new Exception('卡号不存在或未绑定');
            }
            $offline = OfflinePay::add($user->id, $shop_id, $price, $cardNum, $remark);
            OfflinePay::pay($offline->order_id, $pay_pwd);
            $transaction->commit();
            return $this->responseJson(0, '', '支付成功');
        } catch (Exception $e) {
            $transaction->rollBack();
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 会员基本信息查询
     * @return array
     */
    public function actionSearch()
    {
        $cardNum = \Yii::$app->request->post('cardNum');
        $model = User::findByCardNum($cardNum);
        if (empty($model)) {
            return $this->responseJson(1, '', '会员卡号错误');
            //return $this->redirect('index');
        }
        $data = [
            "nickname" => $model->nickname,
            "mobile" => $model->mobile,
            "credit" => $model->credit,
        ];
        return $this->responseJson(0, $data, '查询信息成功');
        //return $this->render('search',['model'=>$model]);
    }

    /**
     * 商家绑定会员卡
     * @return array|string
     */
    public function actionOpenCard()
    {
        $request = \Yii::$app->request;
        $cardNum = $request->post('cardNum');
        $mobile = $request->post('mobile');
        $username = $request->post('username');
        $uid = $request->post('uid');
        try {
            if ($request->post()) {
                $card = OpenCard::findByCardNum($cardNum);
                if (empty($card)) {
                    throw new Exception('该卡号已被绑定');
                }
                if (empty($mobile) || !is_numeric($mobile)) {
                    throw new Exception('请输入正确的会员手机号');
                }
                if (empty($username)) {
                    throw new Exception('请输入会员姓名');
                }
                if (empty($uid) || !is_numeric($uid)) {
                    throw new Exception('请输入正确的会员编号');
                }
                $tel = OpenCard::findByMobile($mobile);
                if (!empty($tel)) {
                    throw new Exception('该会员已绑定过会员卡');
                }
                $sPid = \Yii::$app->user->id;
                $model = User::findByMobile($mobile);
                if ($model->uid != $uid) {
                    throw new Exception('会员手机号和编号不匹配');
                }
                if (empty($model)) {
                    throw new Exception('会员信息不存在');
                }
                OpenCard::add($cardNum, $model->uid, $sPid, $username, $mobile);
                $model->cardNum = $cardNum;
                if ($model->save()) {
                    return $this->responseJson(0, '', '会员卡号绑定成功');
                }
            }
            return $this->render('open-card', ['cardNum' => $cardNum]);
        } catch (Exception $e) {
            return $this->responseJson(1, '', $e->getMessage());
        }
    }

    /**
     * 会员流水查询
     */
    public function actionOrderSearch()
    {
        $tablePrefix = \Yii::$app->db->tablePrefix;
        $request = \Yii::$app->request;
        $cardNum = $request->post('cardNum');
        $page = $request->post('page') ?: 0;

        $searchArr = ['date' => ['start' => date('2017-01-01 00:00'), 'end' => date('Y-m-d H:i')]];
        $query = OfflinePay::find()->orderBy('created_at desc');
        $date = $request->get('date', []);
        if (!empty($date)) {
            $tmp = explode(DateRangePicker::SEPARATOR, $date);
            $searchArr['date'] = ['start' => $tmp['0'], 'end' => $tmp['1']];
            $query->andWhere(['between', "{$tablePrefix}offline_pay.created_at", strtotime($tmp['0']), strtotime($tmp['1'])]);
        }
        $model = $query->offset($page * 10)->limit(10)->all();
        if (!empty($cardNum)) {
            if (!empty($model)) {
                return $this->responseJson(0, $model, '返回信息成功');
            } else {
                return $this->responseJson(1, '', '暂无消费记录');
            }
        }
        return $this->render('order-search', ['model' => $model]);

    }

    /**
     * @return string
     */
    public function actionLeftSlide()
    {
        $cardNum = \Yii::$app->request->post('cardNum');
        $price = \Yii::$app->request->post('price');
        return $this->render('left-slide', ['cardNum' => $cardNum, 'price' => $price]);

    }

}
